import typing

import android.app
import android.content
import android.content.pm
import android.os
import java
import java.chaquopy
import java.lang
import java.util

class PageRange(android.os.Parcelable):
    ALL_PAGES: typing.ClassVar[PageRange] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PageRange]] = ...
    def __init__(self, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getEnd(self) -> int: ...
    def getStart(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class PrintAttributes(android.os.Parcelable):
    COLOR_MODE_COLOR: typing.ClassVar[int] = ...
    COLOR_MODE_MONOCHROME: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PrintAttributes]] = ...
    DUPLEX_MODE_LONG_EDGE: typing.ClassVar[int] = ...
    DUPLEX_MODE_NONE: typing.ClassVar[int] = ...
    DUPLEX_MODE_SHORT_EDGE: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getColorMode(self) -> int: ...
    def getDuplexMode(self) -> int: ...
    def getMediaSize(self) -> PrintAttributes.MediaSize | None: ...
    def getMinMargins(self) -> PrintAttributes.Margins | None: ...
    def getResolution(self) -> PrintAttributes.Resolution | None: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Resolution(java.lang.Object):
        def __init__(self, id: str | java.lang.String, label: str | java.lang.String, horizontalDpi: int | java.jint | java.lang.Integer, verticalDpi: int | java.jint | java.lang.Integer, /) -> None: ...
        def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getHorizontalDpi(self) -> int: ...
        def getId(self) -> str: ...
        def getLabel(self) -> str: ...
        def getVerticalDpi(self) -> int: ...
        def hashCode(self) -> int: ...
        def toString(self) -> str: ...

    class MediaSize(java.lang.Object):
        ANSI_C: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ANSI_D: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ANSI_E: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ANSI_F: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ISO_A0: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ISO_A10: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ISO_A1: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ISO_A2: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ISO_A3: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ISO_A4: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ISO_A5: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ISO_A6: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ISO_A7: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ISO_A8: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ISO_A9: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ISO_B0: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ISO_B10: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ISO_B1: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ISO_B2: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ISO_B3: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ISO_B4: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ISO_B5: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ISO_B6: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ISO_B7: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ISO_B8: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ISO_B9: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ISO_C0: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ISO_C10: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ISO_C1: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ISO_C2: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ISO_C3: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ISO_C4: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ISO_C5: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ISO_C6: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ISO_C7: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ISO_C8: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ISO_C9: typing.ClassVar[PrintAttributes.MediaSize] = ...
        JIS_B0: typing.ClassVar[PrintAttributes.MediaSize] = ...
        JIS_B10: typing.ClassVar[PrintAttributes.MediaSize] = ...
        JIS_B1: typing.ClassVar[PrintAttributes.MediaSize] = ...
        JIS_B2: typing.ClassVar[PrintAttributes.MediaSize] = ...
        JIS_B3: typing.ClassVar[PrintAttributes.MediaSize] = ...
        JIS_B4: typing.ClassVar[PrintAttributes.MediaSize] = ...
        JIS_B5: typing.ClassVar[PrintAttributes.MediaSize] = ...
        JIS_B6: typing.ClassVar[PrintAttributes.MediaSize] = ...
        JIS_B7: typing.ClassVar[PrintAttributes.MediaSize] = ...
        JIS_B8: typing.ClassVar[PrintAttributes.MediaSize] = ...
        JIS_B9: typing.ClassVar[PrintAttributes.MediaSize] = ...
        JIS_EXEC: typing.ClassVar[PrintAttributes.MediaSize] = ...
        JPN_CHOU2: typing.ClassVar[PrintAttributes.MediaSize] = ...
        JPN_CHOU3: typing.ClassVar[PrintAttributes.MediaSize] = ...
        JPN_CHOU4: typing.ClassVar[PrintAttributes.MediaSize] = ...
        JPN_HAGAKI: typing.ClassVar[PrintAttributes.MediaSize] = ...
        JPN_KAHU: typing.ClassVar[PrintAttributes.MediaSize] = ...
        JPN_KAKU2: typing.ClassVar[PrintAttributes.MediaSize] = ...
        JPN_OE_PHOTO_L: typing.ClassVar[PrintAttributes.MediaSize] = ...
        JPN_OUFUKU: typing.ClassVar[PrintAttributes.MediaSize] = ...
        JPN_YOU4: typing.ClassVar[PrintAttributes.MediaSize] = ...
        NA_ARCH_A: typing.ClassVar[PrintAttributes.MediaSize] = ...
        NA_ARCH_B: typing.ClassVar[PrintAttributes.MediaSize] = ...
        NA_ARCH_C: typing.ClassVar[PrintAttributes.MediaSize] = ...
        NA_ARCH_D: typing.ClassVar[PrintAttributes.MediaSize] = ...
        NA_ARCH_E1: typing.ClassVar[PrintAttributes.MediaSize] = ...
        NA_ARCH_E: typing.ClassVar[PrintAttributes.MediaSize] = ...
        NA_FOOLSCAP: typing.ClassVar[PrintAttributes.MediaSize] = ...
        NA_GOVT_LETTER: typing.ClassVar[PrintAttributes.MediaSize] = ...
        NA_INDEX_3X5: typing.ClassVar[PrintAttributes.MediaSize] = ...
        NA_INDEX_4X6: typing.ClassVar[PrintAttributes.MediaSize] = ...
        NA_INDEX_5X8: typing.ClassVar[PrintAttributes.MediaSize] = ...
        NA_JUNIOR_LEGAL: typing.ClassVar[PrintAttributes.MediaSize] = ...
        NA_LEDGER: typing.ClassVar[PrintAttributes.MediaSize] = ...
        NA_LEGAL: typing.ClassVar[PrintAttributes.MediaSize] = ...
        NA_LETTER: typing.ClassVar[PrintAttributes.MediaSize] = ...
        NA_MONARCH: typing.ClassVar[PrintAttributes.MediaSize] = ...
        NA_QUARTO: typing.ClassVar[PrintAttributes.MediaSize] = ...
        NA_SUPER_B: typing.ClassVar[PrintAttributes.MediaSize] = ...
        NA_TABLOID: typing.ClassVar[PrintAttributes.MediaSize] = ...
        OM_DAI_PA_KAI: typing.ClassVar[PrintAttributes.MediaSize] = ...
        OM_JUURO_KU_KAI: typing.ClassVar[PrintAttributes.MediaSize] = ...
        OM_PA_KAI: typing.ClassVar[PrintAttributes.MediaSize] = ...
        PRC_10: typing.ClassVar[PrintAttributes.MediaSize] = ...
        PRC_16K: typing.ClassVar[PrintAttributes.MediaSize] = ...
        PRC_1: typing.ClassVar[PrintAttributes.MediaSize] = ...
        PRC_2: typing.ClassVar[PrintAttributes.MediaSize] = ...
        PRC_3: typing.ClassVar[PrintAttributes.MediaSize] = ...
        PRC_4: typing.ClassVar[PrintAttributes.MediaSize] = ...
        PRC_5: typing.ClassVar[PrintAttributes.MediaSize] = ...
        PRC_6: typing.ClassVar[PrintAttributes.MediaSize] = ...
        PRC_7: typing.ClassVar[PrintAttributes.MediaSize] = ...
        PRC_8: typing.ClassVar[PrintAttributes.MediaSize] = ...
        PRC_9: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ROC_16K: typing.ClassVar[PrintAttributes.MediaSize] = ...
        ROC_8K: typing.ClassVar[PrintAttributes.MediaSize] = ...
        UNKNOWN_LANDSCAPE: typing.ClassVar[PrintAttributes.MediaSize] = ...
        UNKNOWN_PORTRAIT: typing.ClassVar[PrintAttributes.MediaSize] = ...
        def __init__(self, id: str | java.lang.String, label: str | java.lang.String, widthMils: int | java.jint | java.lang.Integer, heightMils: int | java.jint | java.lang.Integer, /) -> None: ...
        def asLandscape(self) -> PrintAttributes.MediaSize: ...
        def asPortrait(self) -> PrintAttributes.MediaSize: ...
        def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getHeightMils(self) -> int: ...
        def getId(self) -> str: ...
        def getLabel(self, packageManager: android.content.pm.PackageManager, /) -> str: ...
        def getWidthMils(self) -> int: ...
        def hashCode(self) -> int: ...
        def isPortrait(self) -> bool: ...
        def toString(self) -> str: ...

    class Margins(java.lang.Object):
        NO_MARGINS: typing.ClassVar[PrintAttributes.Margins] = ...
        def __init__(self, leftMils: int | java.jint | java.lang.Integer, topMils: int | java.jint | java.lang.Integer, rightMils: int | java.jint | java.lang.Integer, bottomMils: int | java.jint | java.lang.Integer, /) -> None: ...
        def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getBottomMils(self) -> int: ...
        def getLeftMils(self) -> int: ...
        def getRightMils(self) -> int: ...
        def getTopMils(self) -> int: ...
        def hashCode(self) -> int: ...
        def toString(self) -> str: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> PrintAttributes: ...
        def setColorMode(self, colorMode: int | java.jint | java.lang.Integer, /) -> PrintAttributes.Builder: ...
        def setDuplexMode(self, duplexMode: int | java.jint | java.lang.Integer, /) -> PrintAttributes.Builder: ...
        def setMediaSize(self, mediaSize: PrintAttributes.MediaSize, /) -> PrintAttributes.Builder: ...
        def setMinMargins(self, margins: PrintAttributes.Margins, /) -> PrintAttributes.Builder: ...
        def setResolution(self, resolution: PrintAttributes.Resolution, /) -> PrintAttributes.Builder: ...

class PrintDocumentAdapter(java.lang.Object):
    EXTRA_PRINT_PREVIEW: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    def onFinish(self) -> None: ...
    def onLayout(self, arg1: PrintAttributes, arg2: PrintAttributes, arg3: android.os.CancellationSignal, arg4: PrintDocumentAdapter.LayoutResultCallback, arg5: android.os.Bundle, /) -> None: ...
    def onStart(self) -> None: ...
    def onWrite(self, arg1: java.chaquopy.JavaArray[PageRange], arg2: android.os.ParcelFileDescriptor, arg3: android.os.CancellationSignal, arg4: PrintDocumentAdapter.WriteResultCallback, /) -> None: ...

    class WriteResultCallback(java.lang.Object):
        def onWriteCancelled(self) -> None: ...
        def onWriteFailed(self, error: java.lang.CharSequence, /) -> None: ...
        def onWriteFinished(self, pages: java.chaquopy.JavaArray[PageRange], /) -> None: ...

    class LayoutResultCallback(java.lang.Object):
        def onLayoutCancelled(self) -> None: ...
        def onLayoutFailed(self, error: java.lang.CharSequence, /) -> None: ...
        def onLayoutFinished(self, info: PrintDocumentInfo, changed: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class PrintDocumentInfo(android.os.Parcelable):
    CONTENT_TYPE_DOCUMENT: typing.ClassVar[int] = ...
    CONTENT_TYPE_PHOTO: typing.ClassVar[int] = ...
    CONTENT_TYPE_UNKNOWN: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PrintDocumentInfo]] = ...
    PAGE_COUNT_UNKNOWN: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getContentType(self) -> int: ...
    def getDataSize(self) -> int: ...
    def getName(self) -> str: ...
    def getPageCount(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, name: str | java.lang.String, /) -> None: ...
        def build(self) -> PrintDocumentInfo: ...
        def setContentType(self, type: int | java.jint | java.lang.Integer, /) -> PrintDocumentInfo.Builder: ...
        def setPageCount(self, pageCount: int | java.jint | java.lang.Integer, /) -> PrintDocumentInfo.Builder: ...

class PrintJob(java.lang.Object):
    def cancel(self) -> None: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getId(self) -> PrintJobId | None: ...
    def getInfo(self) -> PrintJobInfo: ...
    def hashCode(self) -> int: ...
    def isBlocked(self) -> bool: ...
    def isCancelled(self) -> bool: ...
    def isCompleted(self) -> bool: ...
    def isFailed(self) -> bool: ...
    def isQueued(self) -> bool: ...
    def isStarted(self) -> bool: ...
    def restart(self) -> None: ...

class PrintJobId(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PrintJobId]] = ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class PrintJobInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PrintJobInfo]] = ...
    STATE_BLOCKED: typing.ClassVar[int] = ...
    STATE_CANCELED: typing.ClassVar[int] = ...
    STATE_COMPLETED: typing.ClassVar[int] = ...
    STATE_CREATED: typing.ClassVar[int] = ...
    STATE_FAILED: typing.ClassVar[int] = ...
    STATE_QUEUED: typing.ClassVar[int] = ...
    STATE_STARTED: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def getAdvancedIntOption(self, key: str | java.lang.String, /) -> int: ...
    def getAdvancedStringOption(self, key: str | java.lang.String, /) -> str: ...
    def getAttributes(self) -> PrintAttributes: ...
    def getCopies(self) -> int: ...
    def getCreationTime(self) -> int: ...
    def getId(self) -> PrintJobId | None: ...
    def getLabel(self) -> str: ...
    def getPages(self) -> java.chaquopy.JavaArray[PageRange] | None: ...
    def getPrinterId(self) -> PrinterId | None: ...
    def getState(self) -> int: ...
    def hasAdvancedOption(self, key: str | java.lang.String, /) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, prototype: PrintJobInfo, /) -> None: ...
        def build(self) -> PrintJobInfo: ...
        @typing.overload
        def putAdvancedOption(self, key: str | java.lang.String, value: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def putAdvancedOption(self, key: str | java.lang.String, value: str | java.lang.String, /) -> None: ...
        def setAttributes(self, attributes: PrintAttributes, /) -> None: ...
        def setCopies(self, copies: int | java.jint | java.lang.Integer, /) -> None: ...
        def setPages(self, pages: java.chaquopy.JavaArray[PageRange], /) -> None: ...

class PrintManager(java.lang.Object):
    def getPrintJobs(self) -> java.util.List[PrintJob]: ...
    def isPrintServiceEnabled(self, service: android.content.ComponentName, /) -> bool: ...
    def print_(self, printJobName: str | java.lang.String, documentAdapter: PrintDocumentAdapter, attributes: PrintAttributes, /) -> PrintJob | None: ...

class PrinterCapabilitiesInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PrinterCapabilitiesInfo]] = ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getColorModes(self) -> int: ...
    def getDefaults(self) -> PrintAttributes: ...
    def getDuplexModes(self) -> int: ...
    def getMediaSizes(self) -> java.util.List[PrintAttributes.MediaSize]: ...
    def getMinMargins(self) -> PrintAttributes.Margins: ...
    def getResolutions(self) -> java.util.List[PrintAttributes.Resolution]: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, printerId: PrinterId, /) -> None: ...
        def addMediaSize(self, mediaSize: PrintAttributes.MediaSize, isDefault: bool | java.jboolean | java.lang.Boolean, /) -> PrinterCapabilitiesInfo.Builder: ...
        def addResolution(self, resolution: PrintAttributes.Resolution, isDefault: bool | java.jboolean | java.lang.Boolean, /) -> PrinterCapabilitiesInfo.Builder: ...
        def build(self) -> PrinterCapabilitiesInfo: ...
        def setColorModes(self, colorModes: int | java.jint | java.lang.Integer, defaultColorMode: int | java.jint | java.lang.Integer, /) -> PrinterCapabilitiesInfo.Builder: ...
        def setDuplexModes(self, duplexModes: int | java.jint | java.lang.Integer, defaultDuplexMode: int | java.jint | java.lang.Integer, /) -> PrinterCapabilitiesInfo.Builder: ...
        def setMinMargins(self, margins: PrintAttributes.Margins, /) -> PrinterCapabilitiesInfo.Builder: ...

class PrinterId(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PrinterId]] = ...
    def describeContents(self) -> int: ...
    def equals(self, object: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getLocalId(self) -> str: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class PrinterInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PrinterInfo]] = ...
    STATUS_BUSY: typing.ClassVar[int] = ...
    STATUS_IDLE: typing.ClassVar[int] = ...
    STATUS_UNAVAILABLE: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCapabilities(self) -> PrinterCapabilitiesInfo | None: ...
    def getDescription(self) -> str | None: ...
    def getId(self) -> PrinterId: ...
    def getName(self) -> str: ...
    def getStatus(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self, other: PrinterInfo, /) -> None: ...
        @typing.overload
        def __init__(self, printerId: PrinterId, name: str | java.lang.String, status: int | java.jint | java.lang.Integer, /) -> None: ...
        def build(self) -> PrinterInfo: ...
        def setCapabilities(self, capabilities: PrinterCapabilitiesInfo, /) -> PrinterInfo.Builder: ...
        def setDescription(self, description: str | java.lang.String, /) -> PrinterInfo.Builder: ...
        def setHasCustomPrinterIcon(self, hasCustomPrinterIcon: bool | java.jboolean | java.lang.Boolean, /) -> PrinterInfo.Builder: ...
        def setIconResourceId(self, iconResourceId: int | java.jint | java.lang.Integer, /) -> PrinterInfo.Builder: ...
        def setInfoIntent(self, infoIntent: android.app.PendingIntent, /) -> PrinterInfo.Builder: ...
        def setName(self, name: str | java.lang.String, /) -> PrinterInfo.Builder: ...
        def setStatus(self, status: int | java.jint | java.lang.Integer, /) -> PrinterInfo.Builder: ...



import typing

import java
import java.lang
import java.net
import java.nio.channels
import java.util
import java.util.concurrent

class AbstractInterruptibleChannel(java.nio.channels.Channel, java.nio.channels.InterruptibleChannel):
    def __init__(self) -> None: ...
    def begin(self) -> None: ...
    def close(self) -> None: ...
    def end(self, completed: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def implCloseChannel(self) -> None: ...
    def isOpen(self) -> bool: ...

class AbstractSelectableChannel(java.nio.channels.SelectableChannel):
    def __init__(self, provider: SelectorProvider, /) -> None: ...
    def blockingLock(self) -> java.lang.Object: ...
    def configureBlocking(self, block: bool | java.jboolean | java.lang.Boolean, /) -> java.nio.channels.SelectableChannel: ...
    def implCloseChannel(self) -> None: ...
    def implCloseSelectableChannel(self) -> None: ...
    def implConfigureBlocking(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def isBlocking(self) -> bool: ...
    def isRegistered(self) -> bool: ...
    def keyFor(self, sel: java.nio.channels.Selector, /) -> java.nio.channels.SelectionKey: ...
    def provider(self) -> SelectorProvider: ...
    def register(self, sel: java.nio.channels.Selector, ops: int | java.jint | java.lang.Integer, att: java.lang.Object | int | bool | float | str, /) -> java.nio.channels.SelectionKey: ...

class AbstractSelectionKey(java.nio.channels.SelectionKey):
    def __init__(self) -> None: ...
    def cancel(self) -> None: ...
    def isValid(self) -> bool: ...

class AbstractSelector(java.nio.channels.Selector):
    def __init__(self, provider: SelectorProvider, /) -> None: ...
    def begin(self) -> None: ...
    def cancelledKeys(self) -> java.util.Set[java.nio.channels.SelectionKey]: ...
    def close(self) -> None: ...
    def deregister(self, key: AbstractSelectionKey, /) -> None: ...
    def end(self) -> None: ...
    def implCloseSelector(self) -> None: ...
    def isOpen(self) -> bool: ...
    def provider(self) -> SelectorProvider: ...
    def register(self, arg1: AbstractSelectableChannel, arg2: int | java.jint | java.lang.Integer, arg3: java.lang.Object | int | bool | float | str, /) -> java.nio.channels.SelectionKey: ...

class AsynchronousChannelProvider(java.lang.Object):
    def __init__(self) -> None: ...
    @typing.overload
    def openAsynchronousChannelGroup(self, arg1: int | java.jint | java.lang.Integer, arg2: java.util.concurrent.ThreadFactory, /) -> java.nio.channels.AsynchronousChannelGroup: ...
    @typing.overload
    def openAsynchronousChannelGroup(self, arg1: java.util.concurrent.ExecutorService, arg2: int | java.jint | java.lang.Integer, /) -> java.nio.channels.AsynchronousChannelGroup: ...
    def openAsynchronousServerSocketChannel(self, arg1: java.nio.channels.AsynchronousChannelGroup, /) -> java.nio.channels.AsynchronousServerSocketChannel: ...
    def openAsynchronousSocketChannel(self, arg1: java.nio.channels.AsynchronousChannelGroup, /) -> java.nio.channels.AsynchronousSocketChannel: ...
    @staticmethod
    def provider() -> AsynchronousChannelProvider: ...

class SelectorProvider(java.lang.Object):
    def __init__(self) -> None: ...
    def inheritedChannel(self) -> java.nio.channels.Channel: ...
    @typing.overload
    def openDatagramChannel(self) -> java.nio.channels.DatagramChannel: ...
    @typing.overload
    def openDatagramChannel(self, arg1: java.net.ProtocolFamily, /) -> java.nio.channels.DatagramChannel: ...
    def openPipe(self) -> java.nio.channels.Pipe: ...
    def openSelector(self) -> AbstractSelector: ...
    def openServerSocketChannel(self) -> java.nio.channels.ServerSocketChannel: ...
    def openSocketChannel(self) -> java.nio.channels.SocketChannel: ...
    @staticmethod
    def provider() -> SelectorProvider: ...



import typing

import android.content
import java
import java.chaquopy
import java.lang
import java.nio.channels
import java.util.concurrent

class Channel(java.nio.channels.Channel):
    def close(self) -> None: ...
    def getSelectResponse(self) -> java.chaquopy.JavaArrayJByte | None: ...
    def getSession(self) -> Session: ...
    def isBasicChannel(self) -> bool: ...
    def isOpen(self) -> bool: ...
    def selectNext(self) -> bool: ...
    def transmit(self, command: java.chaquopy.JavaArrayJByte, /) -> java.chaquopy.JavaArrayJByte: ...

class Reader(java.lang.Object):
    def closeSessions(self) -> None: ...
    def getName(self) -> str: ...
    def getSEService(self) -> SEService: ...
    def isSecureElementPresent(self) -> bool: ...
    def openSession(self) -> Session: ...

class SEService(java.lang.Object):
    ACTION_SECURE_ELEMENT_STATE_CHANGED: typing.ClassVar[str] = ...
    EXTRA_READER_NAME: typing.ClassVar[str] = ...
    EXTRA_READER_STATE: typing.ClassVar[str] = ...
    def __init__(self, context: android.content.Context, executor: java.util.concurrent.Executor, listener: SEService.OnConnectedListener, /) -> None: ...
    def getReaders(self) -> java.chaquopy.JavaArray[Reader]: ...
    def getUiccReader(self, slotNumber: int | java.jint | java.lang.Integer, /) -> Reader: ...
    def getVersion(self) -> str: ...
    def isConnected(self) -> bool: ...
    def shutdown(self) -> None: ...

    class OnConnectedListener(java.lang.Object):
        def onConnected(self) -> None: ...

class Session(java.lang.Object):
    def close(self) -> None: ...
    def closeChannels(self) -> None: ...
    def getATR(self) -> java.chaquopy.JavaArrayJByte | None: ...
    def getReader(self) -> Reader: ...
    def isClosed(self) -> bool: ...
    @typing.overload
    def openBasicChannel(self, aid: java.chaquopy.JavaArrayJByte, /) -> Channel | None: ...
    @typing.overload
    def openBasicChannel(self, aid: java.chaquopy.JavaArrayJByte, p2: int | java.jbyte | java.lang.Byte, /) -> Channel | None: ...
    @typing.overload
    def openLogicalChannel(self, aid: java.chaquopy.JavaArrayJByte, /) -> Channel | None: ...
    @typing.overload
    def openLogicalChannel(self, aid: java.chaquopy.JavaArrayJByte, p2: int | java.jbyte | java.lang.Byte, /) -> Channel | None: ...



import typing

import java
import java.chaquopy
import java.io
import java.lang
import java.security
import java.util

class AuthPermission(java.security.BasicPermission):
    @typing.overload
    def __init__(self, name: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, name: str | java.lang.String, actions: str | java.lang.String, /) -> None: ...

class DestroyFailedException(java.lang.Exception):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, msg: str | java.lang.String, /) -> None: ...

class Destroyable(java.lang.Object):
    def destroy(self) -> None: ...
    def isDestroyed(self) -> bool: ...

class PrivateCredentialPermission(java.security.Permission):
    def __init__(self, name: str | java.lang.String, actions: str | java.lang.String, /) -> None: ...
    def getActions(self) -> str: ...
    def getCredentialClass(self) -> str: ...
    def getPrincipals(self) -> java.chaquopy.JavaArray[java.chaquopy.JavaArray[java.lang.String]]: ...
    def implies(self, p: java.security.Permission, /) -> bool: ...

class Subject(java.io.Serializable):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, readOnly: bool | java.jboolean | java.lang.Boolean, principals: java.util.Set[java.security.Principal], pubCredentials: java.util.Set[java.lang.Object], privCredentials: java.util.Set[java.lang.Object], /) -> None: ...
    _doAs_0__T = typing.TypeVar('_doAs_0__T')  # <T>
    _doAs_1__T = typing.TypeVar('_doAs_1__T')  # <T>
    @typing.overload
    @staticmethod
    def doAs(subject: Subject, action: java.security.PrivilegedAction[_doAs_0__T], /) -> _doAs_0__T: ...
    @typing.overload
    @staticmethod
    def doAs(subject: Subject, action: java.security.PrivilegedExceptionAction[_doAs_1__T], /) -> _doAs_1__T: ...
    _doAsPrivileged_0__T = typing.TypeVar('_doAsPrivileged_0__T')  # <T>
    _doAsPrivileged_1__T = typing.TypeVar('_doAsPrivileged_1__T')  # <T>
    @typing.overload
    @staticmethod
    def doAsPrivileged(subject: Subject, action: java.security.PrivilegedAction[_doAsPrivileged_0__T], acc: java.security.AccessControlContext, /) -> _doAsPrivileged_0__T: ...
    @typing.overload
    @staticmethod
    def doAsPrivileged(subject: Subject, action: java.security.PrivilegedExceptionAction[_doAsPrivileged_1__T], acc: java.security.AccessControlContext, /) -> _doAsPrivileged_1__T: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    _getPrincipals_1__T = typing.TypeVar('_getPrincipals_1__T')  # <T>
    @typing.overload
    def getPrincipals(self) -> java.util.Set[java.security.Principal]: ...
    @typing.overload
    def getPrincipals(self, c: typing.Type[_getPrincipals_1__T], /) -> java.util.Set[_getPrincipals_1__T]: ...
    _getPrivateCredentials_1__T = typing.TypeVar('_getPrivateCredentials_1__T')  # <T>
    @typing.overload
    def getPrivateCredentials(self) -> java.util.Set[java.lang.Object]: ...
    @typing.overload
    def getPrivateCredentials(self, c: typing.Type[_getPrivateCredentials_1__T], /) -> java.util.Set[_getPrivateCredentials_1__T]: ...
    _getPublicCredentials_1__T = typing.TypeVar('_getPublicCredentials_1__T')  # <T>
    @typing.overload
    def getPublicCredentials(self) -> java.util.Set[java.lang.Object]: ...
    @typing.overload
    def getPublicCredentials(self, c: typing.Type[_getPublicCredentials_1__T], /) -> java.util.Set[_getPublicCredentials_1__T]: ...
    @staticmethod
    def getSubject(acc: java.security.AccessControlContext, /) -> Subject: ...
    def hashCode(self) -> int: ...
    def isReadOnly(self) -> bool: ...
    def setReadOnly(self) -> None: ...
    def toString(self) -> str: ...

class SubjectDomainCombiner(java.security.DomainCombiner):
    def __init__(self, subject: Subject, /) -> None: ...
    def combine(self, currentDomains: java.chaquopy.JavaArray[java.security.ProtectionDomain], assignedDomains: java.chaquopy.JavaArray[java.security.ProtectionDomain], /) -> java.chaquopy.JavaArray[java.security.ProtectionDomain]: ...
    def getSubject(self) -> Subject: ...



import java
import java.chaquopy
import java.lang
import javax.net.ssl

class SSLEngines(java.lang.Object):
    @staticmethod
    def exportKeyingMaterial(engine: javax.net.ssl.SSLEngine, label: str | java.lang.String, context: java.chaquopy.JavaArrayJByte, length: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJByte | None: ...
    @staticmethod
    def isSupportedEngine(engine: javax.net.ssl.SSLEngine, /) -> bool: ...
    @staticmethod
    def setUseSessionTickets(engine: javax.net.ssl.SSLEngine, useSessionTickets: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class SSLSockets(java.lang.Object):
    @staticmethod
    def exportKeyingMaterial(socket: javax.net.ssl.SSLSocket, label: str | java.lang.String, context: java.chaquopy.JavaArrayJByte, length: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJByte | None: ...
    @staticmethod
    def isSupportedSocket(socket: javax.net.ssl.SSLSocket, /) -> bool: ...
    @staticmethod
    def setUseSessionTickets(socket: javax.net.ssl.SSLSocket, useSessionTickets: bool | java.jboolean | java.lang.Boolean, /) -> None: ...



import typing

import android.bluetooth.le
import android.content
import android.os
import java
import java.chaquopy
import java.io
import java.lang
import java.time
import java.util
import java.util.concurrent

class BluetoothA2dp(BluetoothProfile):
    ACTION_CONNECTION_STATE_CHANGED: typing.ClassVar[str] = ...
    ACTION_PLAYING_STATE_CHANGED: typing.ClassVar[str] = ...
    STATE_NOT_PLAYING: typing.ClassVar[int] = ...
    STATE_PLAYING: typing.ClassVar[int] = ...
    def finalize(self) -> None: ...
    def getConnectedDevices(self) -> java.util.List[BluetoothDevice]: ...
    def getConnectionState(self, device: BluetoothDevice, /) -> int: ...
    def getDevicesMatchingConnectionStates(self, states: java.chaquopy.JavaArrayJInt, /) -> java.util.List[BluetoothDevice]: ...
    def getSupportedCodecTypes(self) -> java.util.Collection[BluetoothCodecType]: ...
    def isA2dpPlaying(self, device: BluetoothDevice, /) -> bool: ...

class BluetoothAdapter(java.lang.Object):
    ACTION_CONNECTION_STATE_CHANGED: typing.ClassVar[str] = ...
    ACTION_DISCOVERY_FINISHED: typing.ClassVar[str] = ...
    ACTION_DISCOVERY_STARTED: typing.ClassVar[str] = ...
    ACTION_LOCAL_NAME_CHANGED: typing.ClassVar[str] = ...
    ACTION_REQUEST_DISCOVERABLE: typing.ClassVar[str] = ...
    ACTION_REQUEST_ENABLE: typing.ClassVar[str] = ...
    ACTION_SCAN_MODE_CHANGED: typing.ClassVar[str] = ...
    ACTION_STATE_CHANGED: typing.ClassVar[str] = ...
    ERROR: typing.ClassVar[int] = ...
    EXTRA_CONNECTION_STATE: typing.ClassVar[str] = ...
    EXTRA_DISCOVERABLE_DURATION: typing.ClassVar[str] = ...
    EXTRA_LOCAL_NAME: typing.ClassVar[str] = ...
    EXTRA_PREVIOUS_CONNECTION_STATE: typing.ClassVar[str] = ...
    EXTRA_PREVIOUS_SCAN_MODE: typing.ClassVar[str] = ...
    EXTRA_PREVIOUS_STATE: typing.ClassVar[str] = ...
    EXTRA_SCAN_MODE: typing.ClassVar[str] = ...
    EXTRA_STATE: typing.ClassVar[str] = ...
    SCAN_MODE_CONNECTABLE: typing.ClassVar[int] = ...
    SCAN_MODE_CONNECTABLE_DISCOVERABLE: typing.ClassVar[int] = ...
    SCAN_MODE_NONE: typing.ClassVar[int] = ...
    STATE_CONNECTED: typing.ClassVar[int] = ...
    STATE_CONNECTING: typing.ClassVar[int] = ...
    STATE_DISCONNECTED: typing.ClassVar[int] = ...
    STATE_DISCONNECTING: typing.ClassVar[int] = ...
    STATE_OFF: typing.ClassVar[int] = ...
    STATE_ON: typing.ClassVar[int] = ...
    STATE_TURNING_OFF: typing.ClassVar[int] = ...
    STATE_TURNING_ON: typing.ClassVar[int] = ...
    def cancelDiscovery(self) -> bool: ...
    @staticmethod
    def checkBluetoothAddress(address: str | java.lang.String, /) -> bool: ...
    def closeProfileProxy(self, unusedProfile: int | java.jint | java.lang.Integer, proxy: BluetoothProfile, /) -> None: ...
    def disable(self) -> bool: ...
    def enable(self) -> bool: ...
    def finalize(self) -> None: ...
    def getAddress(self) -> str: ...
    def getBluetoothLeAdvertiser(self) -> android.bluetooth.le.BluetoothLeAdvertiser | None: ...
    def getBluetoothLeScanner(self) -> android.bluetooth.le.BluetoothLeScanner | None: ...
    def getBondedDevices(self) -> java.util.Set[BluetoothDevice]: ...
    @staticmethod
    def getDefaultAdapter() -> BluetoothAdapter | None: ...
    def getDiscoverableTimeout(self) -> java.time.Duration | None: ...
    def getLeMaximumAdvertisingDataLength(self) -> int: ...
    def getMaxConnectedAudioDevices(self) -> int: ...
    def getName(self) -> str | None: ...
    def getProfileConnectionState(self, profile: int | java.jint | java.lang.Integer, /) -> int: ...
    def getProfileProxy(self, context: android.content.Context, listener: BluetoothProfile.ServiceListener, profile: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    def getRemoteDevice(self, address: str | java.lang.String, /) -> BluetoothDevice: ...
    @typing.overload
    def getRemoteDevice(self, address: java.chaquopy.JavaArrayJByte, /) -> BluetoothDevice: ...
    def getRemoteLeDevice(self, address: str | java.lang.String, addressType: int | java.jint | java.lang.Integer, /) -> BluetoothDevice: ...
    def getScanMode(self) -> int: ...
    def getState(self) -> int: ...
    def isDiscovering(self) -> bool: ...
    def isEnabled(self) -> bool: ...
    def isLe2MPhySupported(self) -> bool: ...
    def isLeAudioBroadcastAssistantSupported(self) -> int: ...
    def isLeAudioBroadcastSourceSupported(self) -> int: ...
    def isLeAudioSupported(self) -> int: ...
    def isLeCodedPhySupported(self) -> bool: ...
    def isLeExtendedAdvertisingSupported(self) -> bool: ...
    def isLePeriodicAdvertisingSupported(self) -> bool: ...
    def isMultipleAdvertisementSupported(self) -> bool: ...
    def isOffloadedFilteringSupported(self) -> bool: ...
    def isOffloadedScanBatchingSupported(self) -> bool: ...
    def listenUsingInsecureL2capChannel(self) -> BluetoothServerSocket: ...
    def listenUsingInsecureRfcommWithServiceRecord(self, name: str | java.lang.String, uuid: java.util.UUID, /) -> BluetoothServerSocket: ...
    def listenUsingL2capChannel(self) -> BluetoothServerSocket: ...
    def listenUsingRfcommWithServiceRecord(self, name: str | java.lang.String, uuid: java.util.UUID, /) -> BluetoothServerSocket: ...
    def listenUsingSocketSettings(self, settings: BluetoothSocketSettings, /) -> BluetoothServerSocket: ...
    def setName(self, name: str | java.lang.String, /) -> bool: ...
    def startDiscovery(self) -> bool: ...
    @typing.overload
    def startLeScan(self, callback: BluetoothAdapter.LeScanCallback, /) -> bool: ...
    @typing.overload
    def startLeScan(self, serviceUuids: java.chaquopy.JavaArray[java.util.UUID], callback: BluetoothAdapter.LeScanCallback, /) -> bool: ...
    def stopLeScan(self, callback: BluetoothAdapter.LeScanCallback, /) -> None: ...

    class LeScanCallback(java.lang.Object):
        def onLeScan(self, arg1: BluetoothDevice, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJByte, /) -> None: ...

class BluetoothAssignedNumbers(java.lang.Object):
    AAMP_OF_AMERICA: typing.ClassVar[int] = ...
    ACCEL_SEMICONDUCTOR: typing.ClassVar[int] = ...
    ACE_SENSOR: typing.ClassVar[int] = ...
    ADIDAS: typing.ClassVar[int] = ...
    ADVANCED_PANMOBIL_SYSTEMS: typing.ClassVar[int] = ...
    AIROHA_TECHNOLOGY: typing.ClassVar[int] = ...
    ALCATEL: typing.ClassVar[int] = ...
    ALPWISE: typing.ClassVar[int] = ...
    AMICCOM_ELECTRONICS: typing.ClassVar[int] = ...
    APLIX: typing.ClassVar[int] = ...
    APPLE: typing.ClassVar[int] = ...
    APT_LICENSING: typing.ClassVar[int] = ...
    ARCHOS: typing.ClassVar[int] = ...
    ARP_DEVICES: typing.ClassVar[int] = ...
    ATHEROS_COMMUNICATIONS: typing.ClassVar[int] = ...
    ATMEL: typing.ClassVar[int] = ...
    AUSTCO_COMMUNICATION_SYSTEMS: typing.ClassVar[int] = ...
    AUTONET_MOBILE: typing.ClassVar[int] = ...
    AVAGO: typing.ClassVar[int] = ...
    AVM_BERLIN: typing.ClassVar[int] = ...
    A_AND_D_ENGINEERING: typing.ClassVar[int] = ...
    A_AND_R_CAMBRIDGE: typing.ClassVar[int] = ...
    BANDSPEED: typing.ClassVar[int] = ...
    BAND_XI_INTERNATIONAL: typing.ClassVar[int] = ...
    BDE_TECHNOLOGY: typing.ClassVar[int] = ...
    BEATS_ELECTRONICS: typing.ClassVar[int] = ...
    BEAUTIFUL_ENTERPRISE: typing.ClassVar[int] = ...
    BEKEY: typing.ClassVar[int] = ...
    BELKIN_INTERNATIONAL: typing.ClassVar[int] = ...
    BINAURIC: typing.ClassVar[int] = ...
    BIOSENTRONICS: typing.ClassVar[int] = ...
    BLUEGIGA: typing.ClassVar[int] = ...
    BLUERADIOS: typing.ClassVar[int] = ...
    BLUETOOTH_SIG: typing.ClassVar[int] = ...
    BLUETREK_TECHNOLOGIES: typing.ClassVar[int] = ...
    BOSE: typing.ClassVar[int] = ...
    BRIARTEK: typing.ClassVar[int] = ...
    BROADCOM: typing.ClassVar[int] = ...
    CAEN_RFID: typing.ClassVar[int] = ...
    CAMBRIDGE_SILICON_RADIO: typing.ClassVar[int] = ...
    CATC: typing.ClassVar[int] = ...
    CINETIX: typing.ClassVar[int] = ...
    CLARINOX_TECHNOLOGIES: typing.ClassVar[int] = ...
    COLORFY: typing.ClassVar[int] = ...
    COMMIL: typing.ClassVar[int] = ...
    CONEXANT_SYSTEMS: typing.ClassVar[int] = ...
    CONNECTBLUE: typing.ClassVar[int] = ...
    CONTINENTAL_AUTOMOTIVE: typing.ClassVar[int] = ...
    CONWISE_TECHNOLOGY: typing.ClassVar[int] = ...
    CREATIVE_TECHNOLOGY: typing.ClassVar[int] = ...
    C_TECHNOLOGIES: typing.ClassVar[int] = ...
    DANLERS: typing.ClassVar[int] = ...
    DELORME_PUBLISHING_COMPANY: typing.ClassVar[int] = ...
    DEXCOM: typing.ClassVar[int] = ...
    DIALOG_SEMICONDUCTOR: typing.ClassVar[int] = ...
    DIGIANSWER: typing.ClassVar[int] = ...
    ECLIPSE: typing.ClassVar[int] = ...
    ECOTEST: typing.ClassVar[int] = ...
    ELGATO_SYSTEMS: typing.ClassVar[int] = ...
    EM_MICROELECTRONIC_MARIN: typing.ClassVar[int] = ...
    EQUINOX_AG: typing.ClassVar[int] = ...
    ERICSSON_TECHNOLOGY: typing.ClassVar[int] = ...
    EVLUMA: typing.ClassVar[int] = ...
    FREE2MOVE: typing.ClassVar[int] = ...
    FUNAI_ELECTRIC: typing.ClassVar[int] = ...
    GARMIN_INTERNATIONAL: typing.ClassVar[int] = ...
    GCT_SEMICONDUCTOR: typing.ClassVar[int] = ...
    GELO: typing.ClassVar[int] = ...
    GENEQ: typing.ClassVar[int] = ...
    GENERAL_MOTORS: typing.ClassVar[int] = ...
    GENNUM: typing.ClassVar[int] = ...
    GEOFORCE: typing.ClassVar[int] = ...
    GIBSON_GUITARS: typing.ClassVar[int] = ...
    GN_NETCOM: typing.ClassVar[int] = ...
    GN_RESOUND: typing.ClassVar[int] = ...
    GOOGLE: typing.ClassVar[int] = ...
    GREEN_THROTTLE_GAMES: typing.ClassVar[int] = ...
    GROUP_SENSE: typing.ClassVar[int] = ...
    HANLYNN_TECHNOLOGIES: typing.ClassVar[int] = ...
    HARMAN_INTERNATIONAL: typing.ClassVar[int] = ...
    HEWLETT_PACKARD: typing.ClassVar[int] = ...
    HITACHI: typing.ClassVar[int] = ...
    HOSIDEN: typing.ClassVar[int] = ...
    IBM: typing.ClassVar[int] = ...
    INFINEON_TECHNOLOGIES: typing.ClassVar[int] = ...
    INGENIEUR_SYSTEMGRUPPE_ZAHN: typing.ClassVar[int] = ...
    INTEGRATED_SILICON_SOLUTION: typing.ClassVar[int] = ...
    INTEGRATED_SYSTEM_SOLUTION: typing.ClassVar[int] = ...
    INTEL: typing.ClassVar[int] = ...
    INVENTEL: typing.ClassVar[int] = ...
    IPEXTREME: typing.ClassVar[int] = ...
    I_TECH_DYNAMIC_GLOBAL_DISTRIBUTION: typing.ClassVar[int] = ...
    JAWBONE: typing.ClassVar[int] = ...
    JIANGSU_TOPPOWER_AUTOMOTIVE_ELECTRONICS: typing.ClassVar[int] = ...
    JOHNSON_CONTROLS: typing.ClassVar[int] = ...
    J_AND_M: typing.ClassVar[int] = ...
    KAWANTECH: typing.ClassVar[int] = ...
    KC_TECHNOLOGY: typing.ClassVar[int] = ...
    KENSINGTON_COMPUTER_PRODUCTS_GROUP: typing.ClassVar[int] = ...
    LAIRD_TECHNOLOGIES: typing.ClassVar[int] = ...
    LESSWIRE: typing.ClassVar[int] = ...
    LG_ELECTRONICS: typing.ClassVar[int] = ...
    LINAK: typing.ClassVar[int] = ...
    LUCENT: typing.ClassVar[int] = ...
    LUDUS_HELSINKI: typing.ClassVar[int] = ...
    MACRONIX: typing.ClassVar[int] = ...
    MAGNETI_MARELLI: typing.ClassVar[int] = ...
    MANSELLA: typing.ClassVar[int] = ...
    MARVELL: typing.ClassVar[int] = ...
    MATSUSHITA_ELECTRIC: typing.ClassVar[int] = ...
    MC10: typing.ClassVar[int] = ...
    MEDIATEK: typing.ClassVar[int] = ...
    MESO_INTERNATIONAL: typing.ClassVar[int] = ...
    META_WATCH: typing.ClassVar[int] = ...
    MEWTEL_TECHNOLOGY: typing.ClassVar[int] = ...
    MICOMMAND: typing.ClassVar[int] = ...
    MICROCHIP_TECHNOLOGY: typing.ClassVar[int] = ...
    MICROSOFT: typing.ClassVar[int] = ...
    MINDTREE: typing.ClassVar[int] = ...
    MISFIT_WEARABLES: typing.ClassVar[int] = ...
    MITEL_SEMICONDUCTOR: typing.ClassVar[int] = ...
    MITSUBISHI_ELECTRIC: typing.ClassVar[int] = ...
    MOBILIAN_CORPORATION: typing.ClassVar[int] = ...
    MONSTER: typing.ClassVar[int] = ...
    MOTOROLA: typing.ClassVar[int] = ...
    MSTAR_SEMICONDUCTOR: typing.ClassVar[int] = ...
    MUZIK: typing.ClassVar[int] = ...
    NEC: typing.ClassVar[int] = ...
    NEC_LIGHTING: typing.ClassVar[int] = ...
    NEWLOGIC: typing.ClassVar[int] = ...
    NIKE: typing.ClassVar[int] = ...
    NINE_SOLUTIONS: typing.ClassVar[int] = ...
    NOKIA_MOBILE_PHONES: typing.ClassVar[int] = ...
    NORDIC_SEMICONDUCTOR: typing.ClassVar[int] = ...
    NORWOOD_SYSTEMS: typing.ClassVar[int] = ...
    ODM_TECHNOLOGY: typing.ClassVar[int] = ...
    OMEGAWAVE: typing.ClassVar[int] = ...
    ONSET_COMPUTER: typing.ClassVar[int] = ...
    OPEN_INTERFACE: typing.ClassVar[int] = ...
    OTL_DYNAMICS: typing.ClassVar[int] = ...
    PANDA_OCEAN: typing.ClassVar[int] = ...
    PARROT: typing.ClassVar[int] = ...
    PARTHUS_TECHNOLOGIES: typing.ClassVar[int] = ...
    PASSIF_SEMICONDUCTOR: typing.ClassVar[int] = ...
    PETER_SYSTEMTECHNIK: typing.ClassVar[int] = ...
    PHILIPS_SEMICONDUCTORS: typing.ClassVar[int] = ...
    PLANTRONICS: typing.ClassVar[int] = ...
    POLAR_ELECTRO: typing.ClassVar[int] = ...
    POLAR_ELECTRO_EUROPE: typing.ClassVar[int] = ...
    PROCTER_AND_GAMBLE: typing.ClassVar[int] = ...
    QUALCOMM: typing.ClassVar[int] = ...
    QUALCOMM_CONNECTED_EXPERIENCES: typing.ClassVar[int] = ...
    QUALCOMM_INNOVATION_CENTER: typing.ClassVar[int] = ...
    QUALCOMM_LABS: typing.ClassVar[int] = ...
    QUALCOMM_TECHNOLOGIES: typing.ClassVar[int] = ...
    QUINTIC: typing.ClassVar[int] = ...
    QUUPPA: typing.ClassVar[int] = ...
    RALINK_TECHNOLOGY: typing.ClassVar[int] = ...
    RDA_MICROELECTRONICS: typing.ClassVar[int] = ...
    REALTEK_SEMICONDUCTOR: typing.ClassVar[int] = ...
    RED_M: typing.ClassVar[int] = ...
    RENESAS_TECHNOLOGY: typing.ClassVar[int] = ...
    RESEARCH_IN_MOTION: typing.ClassVar[int] = ...
    RF_MICRO_DEVICES: typing.ClassVar[int] = ...
    RIVIERAWAVES: typing.ClassVar[int] = ...
    ROHDE_AND_SCHWARZ: typing.ClassVar[int] = ...
    RTX_TELECOM: typing.ClassVar[int] = ...
    SAMSUNG_ELECTRONICS: typing.ClassVar[int] = ...
    SARIS_CYCLING_GROUP: typing.ClassVar[int] = ...
    SEERS_TECHNOLOGY: typing.ClassVar[int] = ...
    SEIKO_EPSON: typing.ClassVar[int] = ...
    SELFLY: typing.ClassVar[int] = ...
    SEMILINK: typing.ClassVar[int] = ...
    SENNHEISER_COMMUNICATIONS: typing.ClassVar[int] = ...
    SHANGHAI_SUPER_SMART_ELECTRONICS: typing.ClassVar[int] = ...
    SHENZHEN_EXCELSECU_DATA_TECHNOLOGY: typing.ClassVar[int] = ...
    SIGNIA_TECHNOLOGIES: typing.ClassVar[int] = ...
    SILICON_WAVE: typing.ClassVar[int] = ...
    SIRF_TECHNOLOGY: typing.ClassVar[int] = ...
    SOCKET_MOBILE: typing.ClassVar[int] = ...
    SONY_ERICSSON: typing.ClassVar[int] = ...
    SOUND_ID: typing.ClassVar[int] = ...
    SPORTS_TRACKING_TECHNOLOGIES: typing.ClassVar[int] = ...
    SR_MEDIZINELEKTRONIK: typing.ClassVar[int] = ...
    STACCATO_COMMUNICATIONS: typing.ClassVar[int] = ...
    STALMART_TECHNOLOGY: typing.ClassVar[int] = ...
    STARKEY_LABORATORIES: typing.ClassVar[int] = ...
    STOLLMAN_E_PLUS_V: typing.ClassVar[int] = ...
    STONESTREET_ONE: typing.ClassVar[int] = ...
    ST_MICROELECTRONICS: typing.ClassVar[int] = ...
    SUMMIT_DATA_COMMUNICATIONS: typing.ClassVar[int] = ...
    SUUNTO: typing.ClassVar[int] = ...
    SWIRL_NETWORKS: typing.ClassVar[int] = ...
    SYMBOL_TECHNOLOGIES: typing.ClassVar[int] = ...
    SYNOPSYS: typing.ClassVar[int] = ...
    SYSTEMS_AND_CHIPS: typing.ClassVar[int] = ...
    S_POWER_ELECTRONICS: typing.ClassVar[int] = ...
    TAIXINGBANG_TECHNOLOGY: typing.ClassVar[int] = ...
    TENOVIS: typing.ClassVar[int] = ...
    TERAX: typing.ClassVar[int] = ...
    TEXAS_INSTRUMENTS: typing.ClassVar[int] = ...
    THINKOPTICS: typing.ClassVar[int] = ...
    THREECOM: typing.ClassVar[int] = ...
    THREE_DIJOY: typing.ClassVar[int] = ...
    THREE_DSP: typing.ClassVar[int] = ...
    TIMEKEEPING_SYSTEMS: typing.ClassVar[int] = ...
    TIMEX_GROUP_USA: typing.ClassVar[int] = ...
    TOPCORN_POSITIONING_SYSTEMS: typing.ClassVar[int] = ...
    TOSHIBA: typing.ClassVar[int] = ...
    TRANSILICA: typing.ClassVar[int] = ...
    TRELAB: typing.ClassVar[int] = ...
    TTPCOM: typing.ClassVar[int] = ...
    TXTR: typing.ClassVar[int] = ...
    TZERO_TECHNOLOGIES: typing.ClassVar[int] = ...
    UNIVERSAL_ELECTRONICS: typing.ClassVar[int] = ...
    VERTU: typing.ClassVar[int] = ...
    VISTEON: typing.ClassVar[int] = ...
    VIZIO: typing.ClassVar[int] = ...
    VOYETRA_TURTLE_BEACH: typing.ClassVar[int] = ...
    WAVEPLUS_TECHNOLOGY: typing.ClassVar[int] = ...
    WICENTRIC: typing.ClassVar[int] = ...
    WIDCOMM: typing.ClassVar[int] = ...
    WUXI_VIMICRO: typing.ClassVar[int] = ...
    ZEEVO: typing.ClassVar[int] = ...
    ZER01_TV: typing.ClassVar[int] = ...
    ZOMM: typing.ClassVar[int] = ...
    ZSCAN_SOFTWARE: typing.ClassVar[int] = ...

class BluetoothClass(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[BluetoothClass]] = ...
    PROFILE_A2DP: typing.ClassVar[int] = ...
    PROFILE_HEADSET: typing.ClassVar[int] = ...
    PROFILE_HID: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def doesClassMatch(self, profile: int | java.jint | java.lang.Integer, /) -> bool: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getDeviceClass(self) -> int: ...
    def getMajorDeviceClass(self) -> int: ...
    def hasService(self, service: int | java.jint | java.lang.Integer, /) -> bool: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Service(java.lang.Object):
        AUDIO: typing.ClassVar[int] = ...
        CAPTURE: typing.ClassVar[int] = ...
        INFORMATION: typing.ClassVar[int] = ...
        LE_AUDIO: typing.ClassVar[int] = ...
        LIMITED_DISCOVERABILITY: typing.ClassVar[int] = ...
        NETWORKING: typing.ClassVar[int] = ...
        OBJECT_TRANSFER: typing.ClassVar[int] = ...
        POSITIONING: typing.ClassVar[int] = ...
        RENDER: typing.ClassVar[int] = ...
        TELEPHONY: typing.ClassVar[int] = ...
        def __init__(self) -> None: ...

    class Device(java.lang.Object):
        AUDIO_VIDEO_CAMCORDER: typing.ClassVar[int] = ...
        AUDIO_VIDEO_CAR_AUDIO: typing.ClassVar[int] = ...
        AUDIO_VIDEO_HANDSFREE: typing.ClassVar[int] = ...
        AUDIO_VIDEO_HEADPHONES: typing.ClassVar[int] = ...
        AUDIO_VIDEO_HIFI_AUDIO: typing.ClassVar[int] = ...
        AUDIO_VIDEO_LOUDSPEAKER: typing.ClassVar[int] = ...
        AUDIO_VIDEO_MICROPHONE: typing.ClassVar[int] = ...
        AUDIO_VIDEO_PORTABLE_AUDIO: typing.ClassVar[int] = ...
        AUDIO_VIDEO_SET_TOP_BOX: typing.ClassVar[int] = ...
        AUDIO_VIDEO_UNCATEGORIZED: typing.ClassVar[int] = ...
        AUDIO_VIDEO_VCR: typing.ClassVar[int] = ...
        AUDIO_VIDEO_VIDEO_CAMERA: typing.ClassVar[int] = ...
        AUDIO_VIDEO_VIDEO_CONFERENCING: typing.ClassVar[int] = ...
        AUDIO_VIDEO_VIDEO_DISPLAY_AND_LOUDSPEAKER: typing.ClassVar[int] = ...
        AUDIO_VIDEO_VIDEO_GAMING_TOY: typing.ClassVar[int] = ...
        AUDIO_VIDEO_VIDEO_MONITOR: typing.ClassVar[int] = ...
        AUDIO_VIDEO_WEARABLE_HEADSET: typing.ClassVar[int] = ...
        COMPUTER_DESKTOP: typing.ClassVar[int] = ...
        COMPUTER_HANDHELD_PC_PDA: typing.ClassVar[int] = ...
        COMPUTER_LAPTOP: typing.ClassVar[int] = ...
        COMPUTER_PALM_SIZE_PC_PDA: typing.ClassVar[int] = ...
        COMPUTER_SERVER: typing.ClassVar[int] = ...
        COMPUTER_UNCATEGORIZED: typing.ClassVar[int] = ...
        COMPUTER_WEARABLE: typing.ClassVar[int] = ...
        HEALTH_BLOOD_PRESSURE: typing.ClassVar[int] = ...
        HEALTH_DATA_DISPLAY: typing.ClassVar[int] = ...
        HEALTH_GLUCOSE: typing.ClassVar[int] = ...
        HEALTH_PULSE_OXIMETER: typing.ClassVar[int] = ...
        HEALTH_PULSE_RATE: typing.ClassVar[int] = ...
        HEALTH_THERMOMETER: typing.ClassVar[int] = ...
        HEALTH_UNCATEGORIZED: typing.ClassVar[int] = ...
        HEALTH_WEIGHING: typing.ClassVar[int] = ...
        PERIPHERAL_KEYBOARD: typing.ClassVar[int] = ...
        PERIPHERAL_KEYBOARD_POINTING: typing.ClassVar[int] = ...
        PERIPHERAL_NON_KEYBOARD_NON_POINTING: typing.ClassVar[int] = ...
        PERIPHERAL_POINTING: typing.ClassVar[int] = ...
        PHONE_CELLULAR: typing.ClassVar[int] = ...
        PHONE_CORDLESS: typing.ClassVar[int] = ...
        PHONE_ISDN: typing.ClassVar[int] = ...
        PHONE_MODEM_OR_GATEWAY: typing.ClassVar[int] = ...
        PHONE_SMART: typing.ClassVar[int] = ...
        PHONE_UNCATEGORIZED: typing.ClassVar[int] = ...
        TOY_CONTROLLER: typing.ClassVar[int] = ...
        TOY_DOLL_ACTION_FIGURE: typing.ClassVar[int] = ...
        TOY_GAME: typing.ClassVar[int] = ...
        TOY_ROBOT: typing.ClassVar[int] = ...
        TOY_UNCATEGORIZED: typing.ClassVar[int] = ...
        TOY_VEHICLE: typing.ClassVar[int] = ...
        WEARABLE_GLASSES: typing.ClassVar[int] = ...
        WEARABLE_HELMET: typing.ClassVar[int] = ...
        WEARABLE_JACKET: typing.ClassVar[int] = ...
        WEARABLE_PAGER: typing.ClassVar[int] = ...
        WEARABLE_UNCATEGORIZED: typing.ClassVar[int] = ...
        WEARABLE_WRIST_WATCH: typing.ClassVar[int] = ...
        def __init__(self) -> None: ...

        class Major(java.lang.Object):
            AUDIO_VIDEO: typing.ClassVar[int] = ...
            COMPUTER: typing.ClassVar[int] = ...
            HEALTH: typing.ClassVar[int] = ...
            IMAGING: typing.ClassVar[int] = ...
            MISC: typing.ClassVar[int] = ...
            NETWORKING: typing.ClassVar[int] = ...
            PERIPHERAL: typing.ClassVar[int] = ...
            PHONE: typing.ClassVar[int] = ...
            TOY: typing.ClassVar[int] = ...
            UNCATEGORIZED: typing.ClassVar[int] = ...
            WEARABLE: typing.ClassVar[int] = ...
            def __init__(self) -> None: ...

class BluetoothCodecConfig(android.os.Parcelable):
    BITS_PER_SAMPLE_16: typing.ClassVar[int] = ...
    BITS_PER_SAMPLE_24: typing.ClassVar[int] = ...
    BITS_PER_SAMPLE_32: typing.ClassVar[int] = ...
    BITS_PER_SAMPLE_NONE: typing.ClassVar[int] = ...
    CHANNEL_MODE_MONO: typing.ClassVar[int] = ...
    CHANNEL_MODE_NONE: typing.ClassVar[int] = ...
    CHANNEL_MODE_STEREO: typing.ClassVar[int] = ...
    CODEC_PRIORITY_DEFAULT: typing.ClassVar[int] = ...
    CODEC_PRIORITY_DISABLED: typing.ClassVar[int] = ...
    CODEC_PRIORITY_HIGHEST: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[BluetoothCodecConfig]] = ...
    SAMPLE_RATE_176400: typing.ClassVar[int] = ...
    SAMPLE_RATE_192000: typing.ClassVar[int] = ...
    SAMPLE_RATE_44100: typing.ClassVar[int] = ...
    SAMPLE_RATE_48000: typing.ClassVar[int] = ...
    SAMPLE_RATE_88200: typing.ClassVar[int] = ...
    SAMPLE_RATE_96000: typing.ClassVar[int] = ...
    SAMPLE_RATE_NONE: typing.ClassVar[int] = ...
    SOURCE_CODEC_TYPE_AAC: typing.ClassVar[int] = ...
    SOURCE_CODEC_TYPE_APTX: typing.ClassVar[int] = ...
    SOURCE_CODEC_TYPE_APTX_HD: typing.ClassVar[int] = ...
    SOURCE_CODEC_TYPE_INVALID: typing.ClassVar[int] = ...
    SOURCE_CODEC_TYPE_LC3: typing.ClassVar[int] = ...
    SOURCE_CODEC_TYPE_LDAC: typing.ClassVar[int] = ...
    SOURCE_CODEC_TYPE_OPUS: typing.ClassVar[int] = ...
    SOURCE_CODEC_TYPE_SBC: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getBitsPerSample(self) -> int: ...
    def getChannelMode(self) -> int: ...
    def getCodecPriority(self) -> int: ...
    def getCodecSpecific1(self) -> int: ...
    def getCodecSpecific2(self) -> int: ...
    def getCodecSpecific3(self) -> int: ...
    def getCodecSpecific4(self) -> int: ...
    def getCodecType(self) -> int: ...
    def getExtendedCodecType(self) -> BluetoothCodecType | None: ...
    def getSampleRate(self) -> int: ...
    def hashCode(self) -> int: ...
    def isMandatoryCodec(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> BluetoothCodecConfig: ...
        def setBitsPerSample(self, bitsPerSample: int | java.jint | java.lang.Integer, /) -> BluetoothCodecConfig.Builder: ...
        def setChannelMode(self, channelMode: int | java.jint | java.lang.Integer, /) -> BluetoothCodecConfig.Builder: ...
        def setCodecPriority(self, codecPriority: int | java.jint | java.lang.Integer, /) -> BluetoothCodecConfig.Builder: ...
        def setCodecSpecific1(self, codecSpecific1: int | java.jlong | java.lang.Long, /) -> BluetoothCodecConfig.Builder: ...
        def setCodecSpecific2(self, codecSpecific2: int | java.jlong | java.lang.Long, /) -> BluetoothCodecConfig.Builder: ...
        def setCodecSpecific3(self, codecSpecific3: int | java.jlong | java.lang.Long, /) -> BluetoothCodecConfig.Builder: ...
        def setCodecSpecific4(self, codecSpecific4: int | java.jlong | java.lang.Long, /) -> BluetoothCodecConfig.Builder: ...
        def setCodecType(self, codecType: int | java.jint | java.lang.Integer, /) -> BluetoothCodecConfig.Builder: ...
        def setExtendedCodecType(self, codecType: BluetoothCodecType, /) -> BluetoothCodecConfig.Builder: ...
        def setSampleRate(self, sampleRate: int | java.jint | java.lang.Integer, /) -> BluetoothCodecConfig.Builder: ...

class BluetoothCodecStatus(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[BluetoothCodecStatus]] = ...
    EXTRA_CODEC_STATUS: typing.ClassVar[str] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCodecConfig(self) -> BluetoothCodecConfig | None: ...
    def getCodecsLocalCapabilities(self) -> java.util.List[BluetoothCodecConfig]: ...
    def getCodecsSelectableCapabilities(self) -> java.util.List[BluetoothCodecConfig]: ...
    def hashCode(self) -> int: ...
    def isCodecConfigSelectable(self, codecConfig: BluetoothCodecConfig, /) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> BluetoothCodecStatus: ...
        def setCodecConfig(self, codecConfig: BluetoothCodecConfig, /) -> BluetoothCodecStatus.Builder: ...
        def setCodecsLocalCapabilities(self, codecsLocalCapabilities: java.util.List[BluetoothCodecConfig], /) -> BluetoothCodecStatus.Builder: ...
        def setCodecsSelectableCapabilities(self, codecsSelectableCapabilities: java.util.List[BluetoothCodecConfig], /) -> BluetoothCodecStatus.Builder: ...

class BluetoothCodecType(android.os.Parcelable):
    CODEC_ID_AAC: typing.ClassVar[int] = ...
    CODEC_ID_APTX: typing.ClassVar[int] = ...
    CODEC_ID_APTX_HD: typing.ClassVar[int] = ...
    CODEC_ID_LDAC: typing.ClassVar[int] = ...
    CODEC_ID_OPUS: typing.ClassVar[int] = ...
    CODEC_ID_SBC: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[BluetoothCodecType]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCodecId(self) -> int: ...
    def getCodecName(self) -> str: ...
    def hashCode(self) -> int: ...
    def isMandatoryCodec(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class BluetoothCsipSetCoordinator(BluetoothProfile, java.lang.AutoCloseable):
    ACTION_CSIS_CONNECTION_STATE_CHANGED: typing.ClassVar[str] = ...
    def close(self) -> None: ...
    def finalize(self) -> None: ...
    def getConnectedDevices(self) -> java.util.List[BluetoothDevice]: ...
    def getConnectionState(self, device: BluetoothDevice, /) -> int: ...
    def getDevicesMatchingConnectionStates(self, states: java.chaquopy.JavaArrayJInt, /) -> java.util.List[BluetoothDevice]: ...

class BluetoothDevice(android.os.Parcelable):
    ACTION_ACL_CONNECTED: typing.ClassVar[str] = ...
    ACTION_ACL_DISCONNECTED: typing.ClassVar[str] = ...
    ACTION_ACL_DISCONNECT_REQUESTED: typing.ClassVar[str] = ...
    ACTION_ALIAS_CHANGED: typing.ClassVar[str] = ...
    ACTION_BOND_STATE_CHANGED: typing.ClassVar[str] = ...
    ACTION_CLASS_CHANGED: typing.ClassVar[str] = ...
    ACTION_ENCRYPTION_CHANGE: typing.ClassVar[str] = ...
    ACTION_FOUND: typing.ClassVar[str] = ...
    ACTION_KEY_MISSING: typing.ClassVar[str] = ...
    ACTION_NAME_CHANGED: typing.ClassVar[str] = ...
    ACTION_PAIRING_REQUEST: typing.ClassVar[str] = ...
    ACTION_UUID: typing.ClassVar[str] = ...
    ADDRESS_TYPE_ANONYMOUS: typing.ClassVar[int] = ...
    ADDRESS_TYPE_PUBLIC: typing.ClassVar[int] = ...
    ADDRESS_TYPE_RANDOM: typing.ClassVar[int] = ...
    ADDRESS_TYPE_UNKNOWN: typing.ClassVar[int] = ...
    BOND_BONDED: typing.ClassVar[int] = ...
    BOND_BONDING: typing.ClassVar[int] = ...
    BOND_NONE: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[BluetoothDevice]] = ...
    DEVICE_TYPE_CLASSIC: typing.ClassVar[int] = ...
    DEVICE_TYPE_DUAL: typing.ClassVar[int] = ...
    DEVICE_TYPE_LE: typing.ClassVar[int] = ...
    DEVICE_TYPE_UNKNOWN: typing.ClassVar[int] = ...
    ENCRYPTION_ALGORITHM_AES: typing.ClassVar[int] = ...
    ENCRYPTION_ALGORITHM_E0: typing.ClassVar[int] = ...
    ENCRYPTION_ALGORITHM_NONE: typing.ClassVar[int] = ...
    ERROR: typing.ClassVar[int] = ...
    EXTRA_BOND_STATE: typing.ClassVar[str] = ...
    EXTRA_CLASS: typing.ClassVar[str] = ...
    EXTRA_DEVICE: typing.ClassVar[str] = ...
    EXTRA_ENCRYPTION_ALGORITHM: typing.ClassVar[str] = ...
    EXTRA_ENCRYPTION_ENABLED: typing.ClassVar[str] = ...
    EXTRA_ENCRYPTION_STATUS: typing.ClassVar[str] = ...
    EXTRA_IS_COORDINATED_SET_MEMBER: typing.ClassVar[str] = ...
    EXTRA_KEY_SIZE: typing.ClassVar[str] = ...
    EXTRA_NAME: typing.ClassVar[str] = ...
    EXTRA_PAIRING_KEY: typing.ClassVar[str] = ...
    EXTRA_PAIRING_VARIANT: typing.ClassVar[str] = ...
    EXTRA_PREVIOUS_BOND_STATE: typing.ClassVar[str] = ...
    EXTRA_RSSI: typing.ClassVar[str] = ...
    EXTRA_TRANSPORT: typing.ClassVar[str] = ...
    EXTRA_UUID: typing.ClassVar[str] = ...
    PAIRING_VARIANT_PASSKEY_CONFIRMATION: typing.ClassVar[int] = ...
    PAIRING_VARIANT_PIN: typing.ClassVar[int] = ...
    PHY_LE_1M: typing.ClassVar[int] = ...
    PHY_LE_1M_MASK: typing.ClassVar[int] = ...
    PHY_LE_2M: typing.ClassVar[int] = ...
    PHY_LE_2M_MASK: typing.ClassVar[int] = ...
    PHY_LE_CODED: typing.ClassVar[int] = ...
    PHY_LE_CODED_MASK: typing.ClassVar[int] = ...
    PHY_OPTION_NO_PREFERRED: typing.ClassVar[int] = ...
    PHY_OPTION_S2: typing.ClassVar[int] = ...
    PHY_OPTION_S8: typing.ClassVar[int] = ...
    TRANSPORT_AUTO: typing.ClassVar[int] = ...
    TRANSPORT_BREDR: typing.ClassVar[int] = ...
    TRANSPORT_LE: typing.ClassVar[int] = ...
    @typing.overload
    def connectGatt(self, context: android.content.Context, autoConnect: bool | java.jboolean | java.lang.Boolean, callback: BluetoothGattCallback, /) -> BluetoothGatt | None: ...
    @typing.overload
    def connectGatt(self, context: android.content.Context, autoConnect: bool | java.jboolean | java.lang.Boolean, callback: BluetoothGattCallback, transport: int | java.jint | java.lang.Integer, /) -> BluetoothGatt | None: ...
    @typing.overload
    def connectGatt(self, context: android.content.Context, autoConnect: bool | java.jboolean | java.lang.Boolean, callback: BluetoothGattCallback, transport: int | java.jint | java.lang.Integer, phy: int | java.jint | java.lang.Integer, /) -> BluetoothGatt | None: ...
    @typing.overload
    def connectGatt(self, context: android.content.Context, autoConnect: bool | java.jboolean | java.lang.Boolean, callback: BluetoothGattCallback, transport: int | java.jint | java.lang.Integer, phy: int | java.jint | java.lang.Integer, handler: android.os.Handler, /) -> BluetoothGatt | None: ...
    def createBond(self) -> bool: ...
    def createInsecureL2capChannel(self, psm: int | java.jint | java.lang.Integer, /) -> BluetoothSocket: ...
    def createInsecureRfcommSocketToServiceRecord(self, uuid: java.util.UUID, /) -> BluetoothSocket: ...
    def createL2capChannel(self, psm: int | java.jint | java.lang.Integer, /) -> BluetoothSocket: ...
    def createRfcommSocketToServiceRecord(self, uuid: java.util.UUID, /) -> BluetoothSocket: ...
    def createUsingSocketSettings(self, settings: BluetoothSocketSettings, /) -> BluetoothSocket: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def fetchUuidsWithSdp(self) -> bool: ...
    def getAddress(self) -> str: ...
    def getAddressType(self) -> int: ...
    def getAlias(self) -> str | None: ...
    def getBluetoothClass(self) -> BluetoothClass | None: ...
    def getBondState(self) -> int: ...
    def getIdentityAddressWithType(self) -> BluetoothDevice.BluetoothAddress: ...
    def getName(self) -> str | None: ...
    def getType(self) -> int: ...
    def getUuids(self) -> java.chaquopy.JavaArray[android.os.ParcelUuid] | None: ...
    def hashCode(self) -> int: ...
    def setAlias(self, alias: str | java.lang.String, /) -> int: ...
    def setPairingConfirmation(self, confirm: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def setPin(self, pin: java.chaquopy.JavaArrayJByte, /) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class BluetoothAddress(android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[BluetoothDevice.BluetoothAddress]] = ...
        def __init__(self, address: str | java.lang.String, addressType: int | java.jint | java.lang.Integer, /) -> None: ...
        def describeContents(self) -> int: ...
        def getAddress(self) -> str: ...
        def getAddressType(self) -> int: ...
        def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class BluetoothGatt(BluetoothProfile):
    CONNECTION_PRIORITY_BALANCED: typing.ClassVar[int] = ...
    CONNECTION_PRIORITY_DCK: typing.ClassVar[int] = ...
    CONNECTION_PRIORITY_HIGH: typing.ClassVar[int] = ...
    CONNECTION_PRIORITY_LOW_POWER: typing.ClassVar[int] = ...
    GATT_CONNECTION_CONGESTED: typing.ClassVar[int] = ...
    GATT_CONNECTION_TIMEOUT: typing.ClassVar[int] = ...
    GATT_FAILURE: typing.ClassVar[int] = ...
    GATT_INSUFFICIENT_AUTHENTICATION: typing.ClassVar[int] = ...
    GATT_INSUFFICIENT_AUTHORIZATION: typing.ClassVar[int] = ...
    GATT_INSUFFICIENT_ENCRYPTION: typing.ClassVar[int] = ...
    GATT_INVALID_ATTRIBUTE_LENGTH: typing.ClassVar[int] = ...
    GATT_INVALID_OFFSET: typing.ClassVar[int] = ...
    GATT_READ_NOT_PERMITTED: typing.ClassVar[int] = ...
    GATT_REQUEST_NOT_SUPPORTED: typing.ClassVar[int] = ...
    GATT_SUCCESS: typing.ClassVar[int] = ...
    GATT_WRITE_NOT_PERMITTED: typing.ClassVar[int] = ...
    @typing.overload
    def abortReliableWrite(self) -> None: ...
    @typing.overload
    def abortReliableWrite(self, mDevice: BluetoothDevice, /) -> None: ...
    def beginReliableWrite(self) -> bool: ...
    def close(self) -> None: ...
    def connect(self) -> bool: ...
    def disconnect(self) -> None: ...
    def discoverServices(self) -> bool: ...
    def executeReliableWrite(self) -> bool: ...
    def getConnectedDevices(self) -> java.util.List[BluetoothDevice]: ...
    def getConnectionState(self, device: BluetoothDevice, /) -> int: ...
    def getDevice(self) -> BluetoothDevice: ...
    def getDevicesMatchingConnectionStates(self, states: java.chaquopy.JavaArrayJInt, /) -> java.util.List[BluetoothDevice]: ...
    def getService(self, uuid: java.util.UUID, /) -> BluetoothGattService | None: ...
    def getServices(self) -> java.util.List[BluetoothGattService]: ...
    def readCharacteristic(self, characteristic: BluetoothGattCharacteristic, /) -> bool: ...
    def readDescriptor(self, descriptor: BluetoothGattDescriptor, /) -> bool: ...
    def readPhy(self) -> None: ...
    def readRemoteRssi(self) -> bool: ...
    def requestConnectionPriority(self, connectionPriority: int | java.jint | java.lang.Integer, /) -> bool: ...
    def requestMtu(self, mtu: int | java.jint | java.lang.Integer, /) -> bool: ...
    def setCharacteristicNotification(self, characteristic: BluetoothGattCharacteristic, enable: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def setPreferredPhy(self, txPhy: int | java.jint | java.lang.Integer, rxPhy: int | java.jint | java.lang.Integer, phyOptions: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def writeCharacteristic(self, characteristic: BluetoothGattCharacteristic, /) -> bool: ...
    @typing.overload
    def writeCharacteristic(self, characteristic: BluetoothGattCharacteristic, value: java.chaquopy.JavaArrayJByte, writeType: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def writeDescriptor(self, descriptor: BluetoothGattDescriptor, /) -> bool: ...
    @typing.overload
    def writeDescriptor(self, descriptor: BluetoothGattDescriptor, value: java.chaquopy.JavaArrayJByte, /) -> int: ...

class BluetoothGattCallback(java.lang.Object):
    def __init__(self) -> None: ...
    @typing.overload
    def onCharacteristicChanged(self, gatt: BluetoothGatt, characteristic: BluetoothGattCharacteristic, /) -> None: ...
    @typing.overload
    def onCharacteristicChanged(self, gatt: BluetoothGatt, characteristic: BluetoothGattCharacteristic, value: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def onCharacteristicRead(self, gatt: BluetoothGatt, characteristic: BluetoothGattCharacteristic, status: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def onCharacteristicRead(self, gatt: BluetoothGatt, characteristic: BluetoothGattCharacteristic, value: java.chaquopy.JavaArrayJByte, status: int | java.jint | java.lang.Integer, /) -> None: ...
    def onCharacteristicWrite(self, gatt: BluetoothGatt, characteristic: BluetoothGattCharacteristic, status: int | java.jint | java.lang.Integer, /) -> None: ...
    def onConnectionStateChange(self, gatt: BluetoothGatt, status: int | java.jint | java.lang.Integer, newState: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def onDescriptorRead(self, gatt: BluetoothGatt, descriptor: BluetoothGattDescriptor, status: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def onDescriptorRead(self, gatt: BluetoothGatt, descriptor: BluetoothGattDescriptor, status: int | java.jint | java.lang.Integer, value: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def onDescriptorWrite(self, gatt: BluetoothGatt, descriptor: BluetoothGattDescriptor, status: int | java.jint | java.lang.Integer, /) -> None: ...
    def onMtuChanged(self, gatt: BluetoothGatt, mtu: int | java.jint | java.lang.Integer, status: int | java.jint | java.lang.Integer, /) -> None: ...
    def onPhyRead(self, gatt: BluetoothGatt, txPhy: int | java.jint | java.lang.Integer, rxPhy: int | java.jint | java.lang.Integer, status: int | java.jint | java.lang.Integer, /) -> None: ...
    def onPhyUpdate(self, gatt: BluetoothGatt, txPhy: int | java.jint | java.lang.Integer, rxPhy: int | java.jint | java.lang.Integer, status: int | java.jint | java.lang.Integer, /) -> None: ...
    def onReadRemoteRssi(self, gatt: BluetoothGatt, rssi: int | java.jint | java.lang.Integer, status: int | java.jint | java.lang.Integer, /) -> None: ...
    def onReliableWriteCompleted(self, gatt: BluetoothGatt, status: int | java.jint | java.lang.Integer, /) -> None: ...
    def onServiceChanged(self, gatt: BluetoothGatt, /) -> None: ...
    def onServicesDiscovered(self, gatt: BluetoothGatt, status: int | java.jint | java.lang.Integer, /) -> None: ...

class BluetoothGattCharacteristic(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[BluetoothGattCharacteristic]] = ...
    FORMAT_FLOAT: typing.ClassVar[int] = ...
    FORMAT_SFLOAT: typing.ClassVar[int] = ...
    FORMAT_SINT16: typing.ClassVar[int] = ...
    FORMAT_SINT32: typing.ClassVar[int] = ...
    FORMAT_SINT8: typing.ClassVar[int] = ...
    FORMAT_UINT16: typing.ClassVar[int] = ...
    FORMAT_UINT32: typing.ClassVar[int] = ...
    FORMAT_UINT8: typing.ClassVar[int] = ...
    PERMISSION_READ: typing.ClassVar[int] = ...
    PERMISSION_READ_ENCRYPTED: typing.ClassVar[int] = ...
    PERMISSION_READ_ENCRYPTED_MITM: typing.ClassVar[int] = ...
    PERMISSION_WRITE: typing.ClassVar[int] = ...
    PERMISSION_WRITE_ENCRYPTED: typing.ClassVar[int] = ...
    PERMISSION_WRITE_ENCRYPTED_MITM: typing.ClassVar[int] = ...
    PERMISSION_WRITE_SIGNED: typing.ClassVar[int] = ...
    PERMISSION_WRITE_SIGNED_MITM: typing.ClassVar[int] = ...
    PROPERTY_BROADCAST: typing.ClassVar[int] = ...
    PROPERTY_EXTENDED_PROPS: typing.ClassVar[int] = ...
    PROPERTY_INDICATE: typing.ClassVar[int] = ...
    PROPERTY_NOTIFY: typing.ClassVar[int] = ...
    PROPERTY_READ: typing.ClassVar[int] = ...
    PROPERTY_SIGNED_WRITE: typing.ClassVar[int] = ...
    PROPERTY_WRITE: typing.ClassVar[int] = ...
    PROPERTY_WRITE_NO_RESPONSE: typing.ClassVar[int] = ...
    WRITE_TYPE_DEFAULT: typing.ClassVar[int] = ...
    WRITE_TYPE_NO_RESPONSE: typing.ClassVar[int] = ...
    WRITE_TYPE_SIGNED: typing.ClassVar[int] = ...
    mDescriptors: java.util.List[BluetoothGattDescriptor] = ...
    def __init__(self, uuid: java.util.UUID, properties: int | java.jint | java.lang.Integer, permissions: int | java.jint | java.lang.Integer, /) -> None: ...
    def addDescriptor(self, descriptor: BluetoothGattDescriptor, /) -> bool: ...
    def describeContents(self) -> int: ...
    def getDescriptor(self, uuid: java.util.UUID, /) -> BluetoothGattDescriptor | None: ...
    def getDescriptors(self) -> java.util.List[BluetoothGattDescriptor]: ...
    def getFloatValue(self, formatType: int | java.jint | java.lang.Integer, offset: int | java.jint | java.lang.Integer, /) -> float | None: ...
    def getInstanceId(self) -> int: ...
    def getIntValue(self, formatType: int | java.jint | java.lang.Integer, offset: int | java.jint | java.lang.Integer, /) -> int | None: ...
    def getPermissions(self) -> int: ...
    def getProperties(self) -> int: ...
    def getService(self) -> BluetoothGattService: ...
    def getStringValue(self, offset: int | java.jint | java.lang.Integer, /) -> str: ...
    def getUuid(self) -> java.util.UUID: ...
    def getValue(self) -> java.chaquopy.JavaArrayJByte: ...
    def getWriteType(self) -> int: ...
    @typing.overload
    def setValue(self, value: str | java.lang.String, /) -> bool: ...
    @typing.overload
    def setValue(self, value: java.chaquopy.JavaArrayJByte, /) -> bool: ...
    @typing.overload
    def setValue(self, value: int | java.jint | java.lang.Integer, formatType: int | java.jint | java.lang.Integer, offset: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    def setValue(self, mantissa: int | java.jint | java.lang.Integer, exponent: int | java.jint | java.lang.Integer, formatType: int | java.jint | java.lang.Integer, offset: int | java.jint | java.lang.Integer, /) -> bool: ...
    def setWriteType(self, writeType: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class BluetoothGattDescriptor(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[BluetoothGattDescriptor]] = ...
    DISABLE_NOTIFICATION_VALUE: typing.ClassVar[java.chaquopy.JavaArrayJByte] = ...
    ENABLE_INDICATION_VALUE: typing.ClassVar[java.chaquopy.JavaArrayJByte] = ...
    ENABLE_NOTIFICATION_VALUE: typing.ClassVar[java.chaquopy.JavaArrayJByte] = ...
    PERMISSION_READ: typing.ClassVar[int] = ...
    PERMISSION_READ_ENCRYPTED: typing.ClassVar[int] = ...
    PERMISSION_READ_ENCRYPTED_MITM: typing.ClassVar[int] = ...
    PERMISSION_WRITE: typing.ClassVar[int] = ...
    PERMISSION_WRITE_ENCRYPTED: typing.ClassVar[int] = ...
    PERMISSION_WRITE_ENCRYPTED_MITM: typing.ClassVar[int] = ...
    PERMISSION_WRITE_SIGNED: typing.ClassVar[int] = ...
    PERMISSION_WRITE_SIGNED_MITM: typing.ClassVar[int] = ...
    def __init__(self, uuid: java.util.UUID, permissions: int | java.jint | java.lang.Integer, /) -> None: ...
    def describeContents(self) -> int: ...
    def getCharacteristic(self) -> BluetoothGattCharacteristic: ...
    def getPermissions(self) -> int: ...
    def getUuid(self) -> java.util.UUID: ...
    def getValue(self) -> java.chaquopy.JavaArrayJByte: ...
    def setValue(self, value: java.chaquopy.JavaArrayJByte, /) -> bool: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class BluetoothGattServer(BluetoothProfile):
    def addService(self, service: BluetoothGattService, /) -> bool: ...
    def cancelConnection(self, device: BluetoothDevice, /) -> None: ...
    def clearServices(self) -> None: ...
    def close(self) -> None: ...
    def connect(self, device: BluetoothDevice, autoConnect: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def getConnectedDevices(self) -> java.util.List[BluetoothDevice]: ...
    def getConnectionState(self, device: BluetoothDevice, /) -> int: ...
    def getDevicesMatchingConnectionStates(self, states: java.chaquopy.JavaArrayJInt, /) -> java.util.List[BluetoothDevice]: ...
    def getService(self, uuid: java.util.UUID, /) -> BluetoothGattService | None: ...
    def getServices(self) -> java.util.List[BluetoothGattService]: ...
    @typing.overload
    def notifyCharacteristicChanged(self, device: BluetoothDevice, characteristic: BluetoothGattCharacteristic, confirm: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    @typing.overload
    def notifyCharacteristicChanged(self, device: BluetoothDevice, characteristic: BluetoothGattCharacteristic, confirm: bool | java.jboolean | java.lang.Boolean, value: java.chaquopy.JavaArrayJByte, /) -> int: ...
    def readPhy(self, device: BluetoothDevice, /) -> None: ...
    def removeService(self, service: BluetoothGattService, /) -> bool: ...
    def sendResponse(self, device: BluetoothDevice, requestId: int | java.jint | java.lang.Integer, status: int | java.jint | java.lang.Integer, offset: int | java.jint | java.lang.Integer, value: java.chaquopy.JavaArrayJByte, /) -> bool: ...
    def setPreferredPhy(self, device: BluetoothDevice, txPhy: int | java.jint | java.lang.Integer, rxPhy: int | java.jint | java.lang.Integer, phyOptions: int | java.jint | java.lang.Integer, /) -> None: ...

class BluetoothGattServerCallback(java.lang.Object):
    def __init__(self) -> None: ...
    def onCharacteristicReadRequest(self, device: BluetoothDevice, requestId: int | java.jint | java.lang.Integer, offset: int | java.jint | java.lang.Integer, characteristic: BluetoothGattCharacteristic, /) -> None: ...
    def onCharacteristicWriteRequest(self, device: BluetoothDevice, requestId: int | java.jint | java.lang.Integer, characteristic: BluetoothGattCharacteristic, preparedWrite: bool | java.jboolean | java.lang.Boolean, responseNeeded: bool | java.jboolean | java.lang.Boolean, offset: int | java.jint | java.lang.Integer, value: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def onConnectionStateChange(self, device: BluetoothDevice, status: int | java.jint | java.lang.Integer, newState: int | java.jint | java.lang.Integer, /) -> None: ...
    def onDescriptorReadRequest(self, device: BluetoothDevice, requestId: int | java.jint | java.lang.Integer, offset: int | java.jint | java.lang.Integer, descriptor: BluetoothGattDescriptor, /) -> None: ...
    def onDescriptorWriteRequest(self, device: BluetoothDevice, requestId: int | java.jint | java.lang.Integer, descriptor: BluetoothGattDescriptor, preparedWrite: bool | java.jboolean | java.lang.Boolean, responseNeeded: bool | java.jboolean | java.lang.Boolean, offset: int | java.jint | java.lang.Integer, value: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def onExecuteWrite(self, device: BluetoothDevice, requestId: int | java.jint | java.lang.Integer, execute: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onMtuChanged(self, device: BluetoothDevice, mtu: int | java.jint | java.lang.Integer, /) -> None: ...
    def onNotificationSent(self, device: BluetoothDevice, status: int | java.jint | java.lang.Integer, /) -> None: ...
    def onPhyRead(self, device: BluetoothDevice, txPhy: int | java.jint | java.lang.Integer, rxPhy: int | java.jint | java.lang.Integer, status: int | java.jint | java.lang.Integer, /) -> None: ...
    def onPhyUpdate(self, device: BluetoothDevice, txPhy: int | java.jint | java.lang.Integer, rxPhy: int | java.jint | java.lang.Integer, status: int | java.jint | java.lang.Integer, /) -> None: ...
    def onServiceAdded(self, status: int | java.jint | java.lang.Integer, service: BluetoothGattService, /) -> None: ...

class BluetoothGattService(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[BluetoothGattService]] = ...
    SERVICE_TYPE_PRIMARY: typing.ClassVar[int] = ...
    SERVICE_TYPE_SECONDARY: typing.ClassVar[int] = ...
    mCharacteristics: java.util.List[BluetoothGattCharacteristic] = ...
    mIncludedServices: java.util.List[BluetoothGattService] = ...
    def __init__(self, uuid: java.util.UUID, serviceType: int | java.jint | java.lang.Integer, /) -> None: ...
    def addCharacteristic(self, characteristic: BluetoothGattCharacteristic, /) -> bool: ...
    def addService(self, service: BluetoothGattService, /) -> bool: ...
    def describeContents(self) -> int: ...
    def getCharacteristic(self, uuid: java.util.UUID, /) -> BluetoothGattCharacteristic | None: ...
    def getCharacteristics(self) -> java.util.List[BluetoothGattCharacteristic]: ...
    def getIncludedServices(self) -> java.util.List[BluetoothGattService]: ...
    def getInstanceId(self) -> int: ...
    def getType(self) -> int: ...
    def getUuid(self) -> java.util.UUID: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class BluetoothHeadset(BluetoothProfile):
    ACTION_AUDIO_STATE_CHANGED: typing.ClassVar[str] = ...
    ACTION_CONNECTION_STATE_CHANGED: typing.ClassVar[str] = ...
    ACTION_VENDOR_SPECIFIC_HEADSET_EVENT: typing.ClassVar[str] = ...
    AT_CMD_TYPE_ACTION: typing.ClassVar[int] = ...
    AT_CMD_TYPE_BASIC: typing.ClassVar[int] = ...
    AT_CMD_TYPE_READ: typing.ClassVar[int] = ...
    AT_CMD_TYPE_SET: typing.ClassVar[int] = ...
    AT_CMD_TYPE_TEST: typing.ClassVar[int] = ...
    EXTRA_VENDOR_SPECIFIC_HEADSET_EVENT_ARGS: typing.ClassVar[str] = ...
    EXTRA_VENDOR_SPECIFIC_HEADSET_EVENT_CMD: typing.ClassVar[str] = ...
    EXTRA_VENDOR_SPECIFIC_HEADSET_EVENT_CMD_TYPE: typing.ClassVar[str] = ...
    STATE_AUDIO_CONNECTED: typing.ClassVar[int] = ...
    STATE_AUDIO_CONNECTING: typing.ClassVar[int] = ...
    STATE_AUDIO_DISCONNECTED: typing.ClassVar[int] = ...
    VENDOR_RESULT_CODE_COMMAND_ANDROID: typing.ClassVar[str] = ...
    VENDOR_SPECIFIC_HEADSET_EVENT_COMPANY_ID_CATEGORY: typing.ClassVar[str] = ...
    def finalize(self) -> None: ...
    def getConnectedDevices(self) -> java.util.List[BluetoothDevice]: ...
    def getConnectionState(self, device: BluetoothDevice, /) -> int: ...
    def getDevicesMatchingConnectionStates(self, states: java.chaquopy.JavaArrayJInt, /) -> java.util.List[BluetoothDevice]: ...
    def isAudioConnected(self, device: BluetoothDevice, /) -> bool: ...
    def isNoiseReductionSupported(self, device: BluetoothDevice, /) -> bool: ...
    def isVoiceRecognitionSupported(self, device: BluetoothDevice, /) -> bool: ...
    def sendVendorSpecificResultCode(self, device: BluetoothDevice, command: str | java.lang.String, arg: str | java.lang.String, /) -> bool: ...
    def startVoiceRecognition(self, device: BluetoothDevice, /) -> bool: ...
    def stopVoiceRecognition(self, device: BluetoothDevice, /) -> bool: ...

class BluetoothHealth(BluetoothProfile):
    APP_CONFIG_REGISTRATION_FAILURE: typing.ClassVar[int] = ...
    APP_CONFIG_REGISTRATION_SUCCESS: typing.ClassVar[int] = ...
    APP_CONFIG_UNREGISTRATION_FAILURE: typing.ClassVar[int] = ...
    APP_CONFIG_UNREGISTRATION_SUCCESS: typing.ClassVar[int] = ...
    CHANNEL_TYPE_RELIABLE: typing.ClassVar[int] = ...
    CHANNEL_TYPE_STREAMING: typing.ClassVar[int] = ...
    SINK_ROLE: typing.ClassVar[int] = ...
    SOURCE_ROLE: typing.ClassVar[int] = ...
    STATE_CHANNEL_CONNECTED: typing.ClassVar[int] = ...
    STATE_CHANNEL_CONNECTING: typing.ClassVar[int] = ...
    STATE_CHANNEL_DISCONNECTED: typing.ClassVar[int] = ...
    STATE_CHANNEL_DISCONNECTING: typing.ClassVar[int] = ...
    def connectChannelToSource(self, device: BluetoothDevice, config: BluetoothHealthAppConfiguration, /) -> bool: ...
    def disconnectChannel(self, device: BluetoothDevice, config: BluetoothHealthAppConfiguration, channelId: int | java.jint | java.lang.Integer, /) -> bool: ...
    def getConnectedDevices(self) -> java.util.List[BluetoothDevice]: ...
    def getConnectionState(self, device: BluetoothDevice, /) -> int: ...
    def getDevicesMatchingConnectionStates(self, states: java.chaquopy.JavaArrayJInt, /) -> java.util.List[BluetoothDevice]: ...
    def getMainChannelFd(self, device: BluetoothDevice, config: BluetoothHealthAppConfiguration, /) -> android.os.ParcelFileDescriptor | None: ...
    def registerSinkAppConfiguration(self, name: str | java.lang.String, dataType: int | java.jint | java.lang.Integer, callback: BluetoothHealthCallback, /) -> bool: ...
    def unregisterAppConfiguration(self, config: BluetoothHealthAppConfiguration, /) -> bool: ...

class BluetoothHealthAppConfiguration(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[BluetoothHealthAppConfiguration]] = ...
    def describeContents(self) -> int: ...
    def getDataType(self) -> int: ...
    def getName(self) -> str: ...
    def getRole(self) -> int: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class BluetoothHealthCallback(java.lang.Object):
    def __init__(self) -> None: ...
    def onHealthAppConfigurationStatusChange(self, config: BluetoothHealthAppConfiguration, status: int | java.jint | java.lang.Integer, /) -> None: ...
    def onHealthChannelStateChange(self, config: BluetoothHealthAppConfiguration, device: BluetoothDevice, prevState: int | java.jint | java.lang.Integer, newState: int | java.jint | java.lang.Integer, fd: android.os.ParcelFileDescriptor, channelId: int | java.jint | java.lang.Integer, /) -> None: ...

class BluetoothHearingAid(BluetoothProfile):
    ACTION_CONNECTION_STATE_CHANGED: typing.ClassVar[str] = ...
    def getConnectedDevices(self) -> java.util.List[BluetoothDevice]: ...
    def getConnectionState(self, device: BluetoothDevice, /) -> int: ...
    def getDevicesMatchingConnectionStates(self, states: java.chaquopy.JavaArrayJInt, /) -> java.util.List[BluetoothDevice]: ...

class BluetoothHidDevice(BluetoothProfile):
    ACTION_CONNECTION_STATE_CHANGED: typing.ClassVar[str] = ...
    ERROR_RSP_INVALID_PARAM: typing.ClassVar[int] = ...
    ERROR_RSP_INVALID_RPT_ID: typing.ClassVar[int] = ...
    ERROR_RSP_NOT_READY: typing.ClassVar[int] = ...
    ERROR_RSP_SUCCESS: typing.ClassVar[int] = ...
    ERROR_RSP_UNKNOWN: typing.ClassVar[int] = ...
    ERROR_RSP_UNSUPPORTED_REQ: typing.ClassVar[int] = ...
    PROTOCOL_BOOT_MODE: typing.ClassVar[int] = ...
    PROTOCOL_REPORT_MODE: typing.ClassVar[int] = ...
    REPORT_TYPE_FEATURE: typing.ClassVar[int] = ...
    REPORT_TYPE_INPUT: typing.ClassVar[int] = ...
    REPORT_TYPE_OUTPUT: typing.ClassVar[int] = ...
    SUBCLASS1_COMBO: typing.ClassVar[int] = ...
    SUBCLASS1_KEYBOARD: typing.ClassVar[int] = ...
    SUBCLASS1_MOUSE: typing.ClassVar[int] = ...
    SUBCLASS1_NONE: typing.ClassVar[int] = ...
    SUBCLASS2_CARD_READER: typing.ClassVar[int] = ...
    SUBCLASS2_DIGITIZER_TABLET: typing.ClassVar[int] = ...
    SUBCLASS2_GAMEPAD: typing.ClassVar[int] = ...
    SUBCLASS2_JOYSTICK: typing.ClassVar[int] = ...
    SUBCLASS2_REMOTE_CONTROL: typing.ClassVar[int] = ...
    SUBCLASS2_SENSING_DEVICE: typing.ClassVar[int] = ...
    SUBCLASS2_UNCATEGORIZED: typing.ClassVar[int] = ...
    def connect(self, device: BluetoothDevice, /) -> bool: ...
    def disconnect(self, device: BluetoothDevice, /) -> bool: ...
    def getConnectedDevices(self) -> java.util.List[BluetoothDevice]: ...
    def getConnectionState(self, device: BluetoothDevice, /) -> int: ...
    def getDevicesMatchingConnectionStates(self, states: java.chaquopy.JavaArrayJInt, /) -> java.util.List[BluetoothDevice]: ...
    def registerApp(self, sdp: BluetoothHidDeviceAppSdpSettings, inQos: BluetoothHidDeviceAppQosSettings, outQos: BluetoothHidDeviceAppQosSettings, executor: java.util.concurrent.Executor, callback: BluetoothHidDevice.Callback, /) -> bool: ...
    def replyReport(self, device: BluetoothDevice, type: int | java.jbyte | java.lang.Byte, id: int | java.jbyte | java.lang.Byte, data: java.chaquopy.JavaArrayJByte, /) -> bool: ...
    def reportError(self, device: BluetoothDevice, error: int | java.jbyte | java.lang.Byte, /) -> bool: ...
    def sendReport(self, device: BluetoothDevice, id: int | java.jint | java.lang.Integer, data: java.chaquopy.JavaArrayJByte, /) -> bool: ...
    def unregisterApp(self) -> bool: ...

    class Callback(java.lang.Object):
        def __init__(self) -> None: ...
        def onAppStatusChanged(self, pluggedDevice: BluetoothDevice, registered: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def onConnectionStateChanged(self, device: BluetoothDevice, state: int | java.jint | java.lang.Integer, /) -> None: ...
        def onGetReport(self, device: BluetoothDevice, type: int | java.jbyte | java.lang.Byte, id: int | java.jbyte | java.lang.Byte, bufferSize: int | java.jint | java.lang.Integer, /) -> None: ...
        def onInterruptData(self, device: BluetoothDevice, reportId: int | java.jbyte | java.lang.Byte, data: java.chaquopy.JavaArrayJByte, /) -> None: ...
        def onSetProtocol(self, device: BluetoothDevice, protocol: int | java.jbyte | java.lang.Byte, /) -> None: ...
        def onSetReport(self, device: BluetoothDevice, type: int | java.jbyte | java.lang.Byte, id: int | java.jbyte | java.lang.Byte, data: java.chaquopy.JavaArrayJByte, /) -> None: ...
        def onVirtualCableUnplug(self, device: BluetoothDevice, /) -> None: ...

class BluetoothHidDeviceAppQosSettings(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[BluetoothHidDeviceAppQosSettings]] = ...
    MAX: typing.ClassVar[int] = ...
    SERVICE_BEST_EFFORT: typing.ClassVar[int] = ...
    SERVICE_GUARANTEED: typing.ClassVar[int] = ...
    SERVICE_NO_TRAFFIC: typing.ClassVar[int] = ...
    def __init__(self, serviceType: int | java.jint | java.lang.Integer, tokenRate: int | java.jint | java.lang.Integer, tokenBucketSize: int | java.jint | java.lang.Integer, peakBandwidth: int | java.jint | java.lang.Integer, latency: int | java.jint | java.lang.Integer, delayVariation: int | java.jint | java.lang.Integer, /) -> None: ...
    def describeContents(self) -> int: ...
    def getDelayVariation(self) -> int: ...
    def getLatency(self) -> int: ...
    def getPeakBandwidth(self) -> int: ...
    def getServiceType(self) -> int: ...
    def getTokenBucketSize(self) -> int: ...
    def getTokenRate(self) -> int: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class BluetoothHidDeviceAppSdpSettings(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[BluetoothHidDeviceAppSdpSettings]] = ...
    def __init__(self, name: str | java.lang.String, description: str | java.lang.String, provider: str | java.lang.String, subclass: int | java.jbyte | java.lang.Byte, descriptors: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def describeContents(self) -> int: ...
    def getDescription(self) -> str: ...
    def getDescriptors(self) -> java.chaquopy.JavaArrayJByte: ...
    def getName(self) -> str: ...
    def getProvider(self) -> str: ...
    def getSubclass(self) -> int: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class BluetoothLeAudio(BluetoothProfile, java.lang.AutoCloseable):
    ACTION_LE_AUDIO_CONNECTION_STATE_CHANGED: typing.ClassVar[str] = ...
    GROUP_ID_INVALID: typing.ClassVar[int] = ...
    def close(self) -> None: ...
    def finalize(self) -> None: ...
    def getConnectedDevices(self) -> java.util.List[BluetoothDevice]: ...
    def getConnectedGroupLeadDevice(self, groupId: int | java.jint | java.lang.Integer, /) -> BluetoothDevice | None: ...
    def getConnectionState(self, device: BluetoothDevice, /) -> int: ...
    def getDevicesMatchingConnectionStates(self, states: java.chaquopy.JavaArrayJInt, /) -> java.util.List[BluetoothDevice]: ...
    def getGroupId(self, device: BluetoothDevice, /) -> int: ...

class BluetoothLeAudioCodecConfig(android.os.Parcelable):
    BITS_PER_SAMPLE_16: typing.ClassVar[int] = ...
    BITS_PER_SAMPLE_24: typing.ClassVar[int] = ...
    BITS_PER_SAMPLE_32: typing.ClassVar[int] = ...
    BITS_PER_SAMPLE_NONE: typing.ClassVar[int] = ...
    CHANNEL_COUNT_1: typing.ClassVar[int] = ...
    CHANNEL_COUNT_2: typing.ClassVar[int] = ...
    CHANNEL_COUNT_NONE: typing.ClassVar[int] = ...
    CODEC_PRIORITY_DEFAULT: typing.ClassVar[int] = ...
    CODEC_PRIORITY_DISABLED: typing.ClassVar[int] = ...
    CODEC_PRIORITY_HIGHEST: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[BluetoothLeAudioCodecConfig]] = ...
    FRAME_DURATION_10000: typing.ClassVar[int] = ...
    FRAME_DURATION_7500: typing.ClassVar[int] = ...
    FRAME_DURATION_NONE: typing.ClassVar[int] = ...
    SAMPLE_RATE_11025: typing.ClassVar[int] = ...
    SAMPLE_RATE_16000: typing.ClassVar[int] = ...
    SAMPLE_RATE_176400: typing.ClassVar[int] = ...
    SAMPLE_RATE_192000: typing.ClassVar[int] = ...
    SAMPLE_RATE_22050: typing.ClassVar[int] = ...
    SAMPLE_RATE_24000: typing.ClassVar[int] = ...
    SAMPLE_RATE_32000: typing.ClassVar[int] = ...
    SAMPLE_RATE_384000: typing.ClassVar[int] = ...
    SAMPLE_RATE_44100: typing.ClassVar[int] = ...
    SAMPLE_RATE_48000: typing.ClassVar[int] = ...
    SAMPLE_RATE_8000: typing.ClassVar[int] = ...
    SAMPLE_RATE_88200: typing.ClassVar[int] = ...
    SAMPLE_RATE_96000: typing.ClassVar[int] = ...
    SAMPLE_RATE_NONE: typing.ClassVar[int] = ...
    SOURCE_CODEC_TYPE_INVALID: typing.ClassVar[int] = ...
    SOURCE_CODEC_TYPE_LC3: typing.ClassVar[int] = ...
    SOURCE_CODEC_TYPE_OPUS: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getBitsPerSample(self) -> int: ...
    def getChannelCount(self) -> int: ...
    def getCodecName(self) -> str: ...
    def getCodecPriority(self) -> int: ...
    def getCodecType(self) -> int: ...
    def getFrameDuration(self) -> int: ...
    def getMaxOctetsPerFrame(self) -> int: ...
    def getMinOctetsPerFrame(self) -> int: ...
    def getOctetsPerFrame(self) -> int: ...
    def getSampleRate(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, config: BluetoothLeAudioCodecConfig, /) -> None: ...
        def build(self) -> BluetoothLeAudioCodecConfig: ...
        def setBitsPerSample(self, bitsPerSample: int | java.jint | java.lang.Integer, /) -> BluetoothLeAudioCodecConfig.Builder: ...
        def setChannelCount(self, channelCount: int | java.jint | java.lang.Integer, /) -> BluetoothLeAudioCodecConfig.Builder: ...
        def setCodecPriority(self, codecPriority: int | java.jint | java.lang.Integer, /) -> BluetoothLeAudioCodecConfig.Builder: ...
        def setCodecType(self, codecType: int | java.jint | java.lang.Integer, /) -> BluetoothLeAudioCodecConfig.Builder: ...
        def setFrameDuration(self, frameDuration: int | java.jint | java.lang.Integer, /) -> BluetoothLeAudioCodecConfig.Builder: ...
        def setMaxOctetsPerFrame(self, maxOctetsPerFrame: int | java.jint | java.lang.Integer, /) -> BluetoothLeAudioCodecConfig.Builder: ...
        def setMinOctetsPerFrame(self, minOctetsPerFrame: int | java.jint | java.lang.Integer, /) -> BluetoothLeAudioCodecConfig.Builder: ...
        def setOctetsPerFrame(self, octetsPerFrame: int | java.jint | java.lang.Integer, /) -> BluetoothLeAudioCodecConfig.Builder: ...
        def setSampleRate(self, sampleRate: int | java.jint | java.lang.Integer, /) -> BluetoothLeAudioCodecConfig.Builder: ...

class BluetoothLeAudioCodecStatus(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[BluetoothLeAudioCodecStatus]] = ...
    EXTRA_LE_AUDIO_CODEC_STATUS: typing.ClassVar[str] = ...
    def __init__(self, inputCodecConfig: BluetoothLeAudioCodecConfig, outputCodecConfig: BluetoothLeAudioCodecConfig, inputCodecsLocalCapabilities: java.util.List[BluetoothLeAudioCodecConfig], outputCodecsLocalCapabilities: java.util.List[BluetoothLeAudioCodecConfig], inputCodecsSelectableCapabilities: java.util.List[BluetoothLeAudioCodecConfig], outputCodecsSelectableCapabilities: java.util.List[BluetoothLeAudioCodecConfig], /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getInputCodecConfig(self) -> BluetoothLeAudioCodecConfig | None: ...
    def getInputCodecLocalCapabilities(self) -> java.util.List[BluetoothLeAudioCodecConfig]: ...
    def getInputCodecSelectableCapabilities(self) -> java.util.List[BluetoothLeAudioCodecConfig]: ...
    def getOutputCodecConfig(self) -> BluetoothLeAudioCodecConfig | None: ...
    def getOutputCodecLocalCapabilities(self) -> java.util.List[BluetoothLeAudioCodecConfig]: ...
    def getOutputCodecSelectableCapabilities(self) -> java.util.List[BluetoothLeAudioCodecConfig]: ...
    def hashCode(self) -> int: ...
    def isInputCodecConfigSelectable(self, codecConfig: BluetoothLeAudioCodecConfig, /) -> bool: ...
    def isOutputCodecConfigSelectable(self, codecConfig: BluetoothLeAudioCodecConfig, /) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class BluetoothManager(java.lang.Object):
    def getAdapter(self) -> BluetoothAdapter: ...
    def getConnectedDevices(self, profile: int | java.jint | java.lang.Integer, /) -> java.util.List[BluetoothDevice]: ...
    def getConnectionState(self, device: BluetoothDevice, profile: int | java.jint | java.lang.Integer, /) -> int: ...
    def getDevicesMatchingConnectionStates(self, profile: int | java.jint | java.lang.Integer, states: java.chaquopy.JavaArrayJInt, /) -> java.util.List[BluetoothDevice]: ...
    def openGattServer(self, context: android.content.Context, callback: BluetoothGattServerCallback, /) -> BluetoothGattServer: ...

class BluetoothProfile(java.lang.Object):
    A2DP: typing.ClassVar[int] = ...
    CSIP_SET_COORDINATOR: typing.ClassVar[int] = ...
    EXTRA_PREVIOUS_STATE: typing.ClassVar[str] = ...
    EXTRA_STATE: typing.ClassVar[str] = ...
    GATT: typing.ClassVar[int] = ...
    GATT_SERVER: typing.ClassVar[int] = ...
    HAP_CLIENT: typing.ClassVar[int] = ...
    HEADSET: typing.ClassVar[int] = ...
    HEALTH: typing.ClassVar[int] = ...
    HEARING_AID: typing.ClassVar[int] = ...
    HID_DEVICE: typing.ClassVar[int] = ...
    LE_AUDIO: typing.ClassVar[int] = ...
    SAP: typing.ClassVar[int] = ...
    STATE_CONNECTED: typing.ClassVar[int] = ...
    STATE_CONNECTING: typing.ClassVar[int] = ...
    STATE_DISCONNECTED: typing.ClassVar[int] = ...
    STATE_DISCONNECTING: typing.ClassVar[int] = ...
    def getConnectedDevices(self) -> java.util.List[BluetoothDevice]: ...
    def getConnectionState(self, arg1: BluetoothDevice, /) -> int: ...
    def getDevicesMatchingConnectionStates(self, arg1: java.chaquopy.JavaArrayJInt, /) -> java.util.List[BluetoothDevice]: ...

    class ServiceListener(java.lang.Object):
        def onServiceConnected(self, arg1: int | java.jint | java.lang.Integer, arg2: BluetoothProfile, /) -> None: ...
        def onServiceDisconnected(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...

class BluetoothServerSocket(java.io.Closeable):
    @typing.overload
    def accept(self) -> BluetoothSocket: ...
    @typing.overload
    def accept(self, timeout: int | java.jint | java.lang.Integer, /) -> BluetoothSocket: ...
    def close(self) -> None: ...
    def getPsm(self) -> int: ...
    def toString(self) -> str: ...

class BluetoothSocket(java.io.Closeable):
    TYPE_L2CAP: typing.ClassVar[int] = ...
    TYPE_LE: typing.ClassVar[int] = ...
    TYPE_RFCOMM: typing.ClassVar[int] = ...
    TYPE_SCO: typing.ClassVar[int] = ...
    def close(self) -> None: ...
    def connect(self) -> None: ...
    def finalize(self) -> None: ...
    def getConnectionType(self) -> int: ...
    def getInputStream(self) -> java.io.InputStream: ...
    def getMaxReceivePacketSize(self) -> int: ...
    def getMaxTransmitPacketSize(self) -> int: ...
    def getOutputStream(self) -> java.io.OutputStream: ...
    def getRemoteDevice(self) -> BluetoothDevice: ...
    def isConnected(self) -> bool: ...
    def toString(self) -> str: ...

class BluetoothSocketException(java.io.IOException):
    BLUETOOTH_OFF_FAILURE: typing.ClassVar[int] = ...
    L2CAP_ACL_FAILURE: typing.ClassVar[int] = ...
    L2CAP_CLIENT_SECURITY_FAILURE: typing.ClassVar[int] = ...
    L2CAP_INSUFFICIENT_AUTHENTICATION: typing.ClassVar[int] = ...
    L2CAP_INSUFFICIENT_AUTHORIZATION: typing.ClassVar[int] = ...
    L2CAP_INSUFFICIENT_ENCRYPTION: typing.ClassVar[int] = ...
    L2CAP_INSUFFICIENT_ENCRYPT_KEY_SIZE: typing.ClassVar[int] = ...
    L2CAP_INVALID_PARAMETERS: typing.ClassVar[int] = ...
    L2CAP_INVALID_SOURCE_CID: typing.ClassVar[int] = ...
    L2CAP_NO_PSM_AVAILABLE: typing.ClassVar[int] = ...
    L2CAP_NO_RESOURCES: typing.ClassVar[int] = ...
    L2CAP_SOURCE_CID_ALREADY_ALLOCATED: typing.ClassVar[int] = ...
    L2CAP_TIMEOUT: typing.ClassVar[int] = ...
    L2CAP_UNACCEPTABLE_PARAMETERS: typing.ClassVar[int] = ...
    L2CAP_UNKNOWN: typing.ClassVar[int] = ...
    NULL_DEVICE: typing.ClassVar[int] = ...
    RPC_FAILURE: typing.ClassVar[int] = ...
    SOCKET_CLOSED: typing.ClassVar[int] = ...
    SOCKET_CONNECTION_FAILURE: typing.ClassVar[int] = ...
    SOCKET_MANAGER_FAILURE: typing.ClassVar[int] = ...
    UNIX_FILE_SOCKET_CREATION_FAILURE: typing.ClassVar[int] = ...
    UNSPECIFIED: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, code: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, code: int | java.jint | java.lang.Integer, msg: str | java.lang.String, /) -> None: ...
    def getErrorCode(self) -> int: ...

class BluetoothSocketSettings(java.lang.Object):
    def getL2capPsm(self) -> int: ...
    def getRfcommServiceName(self) -> str: ...
    def getRfcommUuid(self) -> java.util.UUID: ...
    def getSocketType(self) -> int: ...
    def isAuthenticationRequired(self) -> bool: ...
    def isEncryptionRequired(self) -> bool: ...
    def toString(self) -> str: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> BluetoothSocketSettings: ...
        def setAuthenticationRequired(self, authenticationRequired: bool | java.jboolean | java.lang.Boolean, /) -> BluetoothSocketSettings.Builder: ...
        def setEncryptionRequired(self, encryptionRequired: bool | java.jboolean | java.lang.Boolean, /) -> BluetoothSocketSettings.Builder: ...
        def setL2capPsm(self, l2capPsm: int | java.jint | java.lang.Integer, /) -> BluetoothSocketSettings.Builder: ...
        def setRfcommServiceName(self, rfcommServiceName: str | java.lang.String, /) -> BluetoothSocketSettings.Builder: ...
        def setRfcommUuid(self, rfcommUuid: java.util.UUID, /) -> BluetoothSocketSettings.Builder: ...
        def setSocketType(self, socketType: int | java.jint | java.lang.Integer, /) -> BluetoothSocketSettings.Builder: ...

class BluetoothStatusCodes(java.lang.Object):
    ERROR_BLUETOOTH_NOT_ALLOWED: typing.ClassVar[int] = ...
    ERROR_BLUETOOTH_NOT_ENABLED: typing.ClassVar[int] = ...
    ERROR_DEVICE_NOT_BONDED: typing.ClassVar[int] = ...
    ERROR_GATT_WRITE_NOT_ALLOWED: typing.ClassVar[int] = ...
    ERROR_GATT_WRITE_REQUEST_BUSY: typing.ClassVar[int] = ...
    ERROR_MISSING_BLUETOOTH_CONNECT_PERMISSION: typing.ClassVar[int] = ...
    ERROR_PROFILE_SERVICE_NOT_BOUND: typing.ClassVar[int] = ...
    ERROR_UNKNOWN: typing.ClassVar[int] = ...
    FEATURE_NOT_CONFIGURED: typing.ClassVar[int] = ...
    FEATURE_NOT_SUPPORTED: typing.ClassVar[int] = ...
    FEATURE_SUPPORTED: typing.ClassVar[int] = ...
    SUCCESS: typing.ClassVar[int] = ...
